Class: Aws::SESV2::Types::BulkEmailEntry
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::BulkEmailEntry
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#destination ⇒ Types::Destination
Represents the destination of the message, consisting of To:, CC:, and BCC: fields.
-
#replacement_email_content ⇒ Types::ReplacementEmailContent
The
ReplacementEmailContentassociated with aBulkEmailEntry. -
#replacement_headers ⇒ Array<Types::MessageHeader>
The list of message headers associated with the
BulkEmailEntrydata type. -
#replacement_tags ⇒ Array<Types::MessageTag>
A list of tags, in the form of name/value pairs, to apply to an email that you send using the
SendBulkTemplatedEmailoperation.
Instance Attribute Details
#destination ⇒ Types::Destination
Represents the destination of the message, consisting of To:, CC:, and BCC: fields.
<note markdown=“1”> Amazon SES does not support the SMTPUTF8 extension, as described in [RFC6531]. For this reason, the local part of a destination email address (the part of the email address that precedes the @ sign) may only contain [7-bit ASCII characters]. If the domain part of an address (the part after the @ sign) contains non-ASCII characters, they must be encoded using Punycode, as described in [RFC3492].
</note>
[1]: tools.ietf.org/html/rfc6531 [2]: en.wikipedia.org/wiki/Email_address#Local-part [3]: tools.ietf.org/html/rfc3492.html
426 427 428 429 430 431 432 433 |
# File 'lib/aws-sdk-sesv2/types.rb', line 426 class BulkEmailEntry < Struct.new( :destination, :replacement_tags, :replacement_email_content, :replacement_headers) SENSITIVE = [] include Aws::Structure end |
#replacement_email_content ⇒ Types::ReplacementEmailContent
The ReplacementEmailContent associated with a BulkEmailEntry.
426 427 428 429 430 431 432 433 |
# File 'lib/aws-sdk-sesv2/types.rb', line 426 class BulkEmailEntry < Struct.new( :destination, :replacement_tags, :replacement_email_content, :replacement_headers) SENSITIVE = [] include Aws::Structure end |
#replacement_headers ⇒ Array<Types::MessageHeader>
The list of message headers associated with the BulkEmailEntry data type.
-
Headers Not Present in
BulkEmailEntry: If a header is specified in [Template][1] but not inBulkEmailEntry, the header fromTemplatewill be added to the outgoing email. -
Headers Present in
BulkEmailEntry: If a header is specified inBulkEmailEntry, it takes precedence over any header of the same name specified in [Template][1]:-
If the header is also defined within
Template, the value fromBulkEmailEntrywill replace the header’s value in the email. -
If the header is not defined within
Template, it will simply be added to the email as specified inBulkEmailEntry.
-
[1]: docs.aws.amazon.com/ses/latest/APIReference-V2/API_Template.html
426 427 428 429 430 431 432 433 |
# File 'lib/aws-sdk-sesv2/types.rb', line 426 class BulkEmailEntry < Struct.new( :destination, :replacement_tags, :replacement_email_content, :replacement_headers) SENSITIVE = [] include Aws::Structure end |
#replacement_tags ⇒ Array<Types::MessageTag>
A list of tags, in the form of name/value pairs, to apply to an email that you send using the SendBulkTemplatedEmail operation. Tags correspond to characteristics of the email that you define, so that you can publish email sending events.
426 427 428 429 430 431 432 433 |
# File 'lib/aws-sdk-sesv2/types.rb', line 426 class BulkEmailEntry < Struct.new( :destination, :replacement_tags, :replacement_email_content, :replacement_headers) SENSITIVE = [] include Aws::Structure end |