Class: Aws::SESV2::Types::CreateDeliverabilityTestReportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::CreateDeliverabilityTestReportResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Information about the predictive inbox placement test that you created.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deliverability_test_status ⇒ String
The status of the predictive inbox placement test.
-
#report_id ⇒ String
A unique string that identifies the predictive inbox placement test.
Instance Attribute Details
#deliverability_test_status ⇒ String
The status of the predictive inbox placement test. If the status is IN_PROGRESS, then the predictive inbox placement test is currently running. Predictive inbox placement tests are usually complete within 24 hours of creating the test. If the status is COMPLETE, then the test is finished, and you can use the GetDeliverabilityTestReport to view the results of the test.
1065 1066 1067 1068 1069 1070 |
# File 'lib/aws-sdk-sesv2/types.rb', line 1065 class CreateDeliverabilityTestReportResponse < Struct.new( :report_id, :deliverability_test_status) SENSITIVE = [] include Aws::Structure end |
#report_id ⇒ String
A unique string that identifies the predictive inbox placement test.
1065 1066 1067 1068 1069 1070 |
# File 'lib/aws-sdk-sesv2/types.rb', line 1065 class CreateDeliverabilityTestReportResponse < Struct.new( :report_id, :deliverability_test_status) SENSITIVE = [] include Aws::Structure end |