Class: Aws::SESV2::Types::CreateEmailIdentityPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

Represents a request to create a sending authorization policy for an identity. Sending authorization is an Amazon SES feature that enables you to authorize other senders to use your identities. For information, see the Amazon SES Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#email_identityString

The email identity.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
# File 'lib/aws-sdk-sesv2/types.rb', line 1131

class CreateEmailIdentityPolicyRequest < Struct.new(
  :email_identity,
  :policy_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end

#policyString

The text of the policy in JSON format. The policy cannot exceed 4 KB.

For information about the syntax of sending authorization policies, see the Amazon SES Developer Guide.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
# File 'lib/aws-sdk-sesv2/types.rb', line 1131

class CreateEmailIdentityPolicyRequest < Struct.new(
  :email_identity,
  :policy_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end

#policy_nameString

The name of the policy.

The policy name cannot exceed 64 characters and can only include alphanumeric characters, dashes, and underscores.

Returns:

  • (String)


1131
1132
1133
1134
1135
1136
1137
# File 'lib/aws-sdk-sesv2/types.rb', line 1131

class CreateEmailIdentityPolicyRequest < Struct.new(
  :email_identity,
  :policy_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end