Class: Aws::SESV2::Types::CreateEmailIdentityResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::CreateEmailIdentityResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
If the email identity is a domain, this object contains information about the DKIM verification status for the domain.
If the email identity is an email address, this object is empty.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dkim_attributes ⇒ Types::DkimAttributes
An object that contains information about the DKIM attributes for the identity.
-
#identity_type ⇒ String
The email identity type.
-
#verified_for_sending_status ⇒ Boolean
Specifies whether or not the identity is verified.
Instance Attribute Details
#dkim_attributes ⇒ Types::DkimAttributes
An object that contains information about the DKIM attributes for the identity.
1216 1217 1218 1219 1220 1221 1222 |
# File 'lib/aws-sdk-sesv2/types.rb', line 1216 class CreateEmailIdentityResponse < Struct.new( :identity_type, :verified_for_sending_status, :dkim_attributes) SENSITIVE = [] include Aws::Structure end |
#identity_type ⇒ String
The email identity type. Note: the MANAGED_DOMAIN identity type is
not supported.
1216 1217 1218 1219 1220 1221 1222 |
# File 'lib/aws-sdk-sesv2/types.rb', line 1216 class CreateEmailIdentityResponse < Struct.new( :identity_type, :verified_for_sending_status, :dkim_attributes) SENSITIVE = [] include Aws::Structure end |
#verified_for_sending_status ⇒ Boolean
Specifies whether or not the identity is verified. You can only send email from verified email addresses or domains. For more information about verifying identities, see the Amazon Pinpoint User Guide.
1216 1217 1218 1219 1220 1221 1222 |
# File 'lib/aws-sdk-sesv2/types.rb', line 1216 class CreateEmailIdentityResponse < Struct.new( :identity_type, :verified_for_sending_status, :dkim_attributes) SENSITIVE = [] include Aws::Structure end |