Class: Aws::SESV2::Types::CreateTenantResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

Information about a newly created tenant.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#created_timestampTime

The date and time when the tenant was created.

Returns:

  • (Time)


1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
# File 'lib/aws-sdk-sesv2/types.rb', line 1466

class CreateTenantResponse < Struct.new(
  :tenant_name,
  :tenant_id,
  :tenant_arn,
  :created_timestamp,
  :tags,
  :sending_status,
  :suppression_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#sending_statusString

The status of email sending capability for the tenant.

Returns:

  • (String)


1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
# File 'lib/aws-sdk-sesv2/types.rb', line 1466

class CreateTenantResponse < Struct.new(
  :tenant_name,
  :tenant_id,
  :tenant_arn,
  :created_timestamp,
  :tags,
  :sending_status,
  :suppression_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#suppression_attributesTypes::TenantSuppressionAttributes

An object that contains the suppression list preferences for a tenant.



1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
# File 'lib/aws-sdk-sesv2/types.rb', line 1466

class CreateTenantResponse < Struct.new(
  :tenant_name,
  :tenant_id,
  :tenant_arn,
  :created_timestamp,
  :tags,
  :sending_status,
  :suppression_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of objects that define the tags (keys and values) associated with the tenant.

Returns:



1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
# File 'lib/aws-sdk-sesv2/types.rb', line 1466

class CreateTenantResponse < Struct.new(
  :tenant_name,
  :tenant_id,
  :tenant_arn,
  :created_timestamp,
  :tags,
  :sending_status,
  :suppression_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_arnString

The Amazon Resource Name (ARN) of the tenant.

Returns:

  • (String)


1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
# File 'lib/aws-sdk-sesv2/types.rb', line 1466

class CreateTenantResponse < Struct.new(
  :tenant_name,
  :tenant_id,
  :tenant_arn,
  :created_timestamp,
  :tags,
  :sending_status,
  :suppression_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_idString

A unique identifier for the tenant.

Returns:

  • (String)


1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
# File 'lib/aws-sdk-sesv2/types.rb', line 1466

class CreateTenantResponse < Struct.new(
  :tenant_name,
  :tenant_id,
  :tenant_arn,
  :created_timestamp,
  :tags,
  :sending_status,
  :suppression_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_nameString

The name of the tenant.

Returns:

  • (String)


1466
1467
1468
1469
1470
1471
1472
1473
1474
1475
1476
# File 'lib/aws-sdk-sesv2/types.rb', line 1466

class CreateTenantResponse < Struct.new(
  :tenant_name,
  :tenant_id,
  :tenant_arn,
  :created_timestamp,
  :tags,
  :sending_status,
  :suppression_attributes)
  SENSITIVE = []
  include Aws::Structure
end