Class: Aws::SESV2::Types::DeleteEmailIdentityRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::DeleteEmailIdentityRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to delete an existing email identity. When you delete an identity, you lose the ability to send email from that identity. You can restore your ability to send email by completing the verification process for the identity again.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#email_identity ⇒ String
The identity (that is, the email address or domain) to delete.
Instance Attribute Details
#email_identity ⇒ String
The identity (that is, the email address or domain) to delete.
1847 1848 1849 1850 1851 |
# File 'lib/aws-sdk-sesv2/types.rb', line 1847 class DeleteEmailIdentityRequest < Struct.new( :email_identity) SENSITIVE = [] include Aws::Structure end |