Class: Aws::SESV2::Types::DeliveryOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::DeliveryOptions
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Used to associate a configuration set with a dedicated IP pool.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_delivery_seconds ⇒ Integer
The maximum amount of time, in seconds, that Amazon SES API v2 will attempt delivery of email.
-
#sending_pool_name ⇒ String
The name of the dedicated IP pool to associate with the configuration set.
-
#tls_policy ⇒ String
Specifies whether messages that use the configuration set are required to use Transport Layer Security (TLS).
Instance Attribute Details
#max_delivery_seconds ⇒ Integer
The maximum amount of time, in seconds, that Amazon SES API v2 will attempt delivery of email. If specified, the value must greater than or equal to 300 seconds (5 minutes) and less than or equal to 50400 seconds (840 minutes).
2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2078 class DeliveryOptions < Struct.new( :tls_policy, :sending_pool_name, :max_delivery_seconds) SENSITIVE = [] include Aws::Structure end |
#sending_pool_name ⇒ String
The name of the dedicated IP pool to associate with the configuration set.
2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2078 class DeliveryOptions < Struct.new( :tls_policy, :sending_pool_name, :max_delivery_seconds) SENSITIVE = [] include Aws::Structure end |
#tls_policy ⇒ String
Specifies whether messages that use the configuration set are required to use Transport Layer Security (TLS). If the value is ‘Require`, messages are only delivered if a TLS connection can be established. If the value is `Optional`, messages can be delivered in plain text if a TLS connection can’t be established.
2078 2079 2080 2081 2082 2083 2084 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2078 class DeliveryOptions < Struct.new( :tls_policy, :sending_pool_name, :max_delivery_seconds) SENSITIVE = [] include Aws::Structure end |