Class: Aws::SESV2::Types::ExportDataSource

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

An object that contains details about the data source of the export job. It can only contain one of MetricsDataSource or MessageInsightsDataSource object.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#message_insights_data_sourceTypes::MessageInsightsDataSource

An object that contains filters applied when performing the Message Insights export.



3157
3158
3159
3160
3161
3162
# File 'lib/aws-sdk-sesv2/types.rb', line 3157

class ExportDataSource < Struct.new(
  :metrics_data_source,
  :message_insights_data_source)
  SENSITIVE = []
  include Aws::Structure
end

#metrics_data_sourceTypes::MetricsDataSource

An object that contains details about the data source for the metrics export.



3157
3158
3159
3160
3161
3162
# File 'lib/aws-sdk-sesv2/types.rb', line 3157

class ExportDataSource < Struct.new(
  :metrics_data_source,
  :message_insights_data_source)
  SENSITIVE = []
  include Aws::Structure
end