Class: Aws::SESV2::Types::GetConfigurationSetResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::GetConfigurationSetResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Information about a configuration set.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#archiving_options ⇒ Types::ArchivingOptions
An object that defines the MailManager archive where sent emails are archived that you send using the configuration set.
-
#configuration_set_name ⇒ String
The name of the configuration set.
-
#delivery_options ⇒ Types::DeliveryOptions
An object that defines the dedicated IP pool that is used to send emails that you send using the configuration set.
-
#reputation_options ⇒ Types::ReputationOptions
An object that defines whether or not Amazon SES collects reputation metrics for the emails that you send that use the configuration set.
-
#sending_options ⇒ Types::SendingOptions
An object that defines whether or not Amazon SES can send email that you send using the configuration set.
-
#suppression_options ⇒ Types::SuppressionOptions
An object that contains information about the suppression list preferences for your account or for a specific tenant.
-
#tags ⇒ Array<Types::Tag>
An array of objects that define the tags (keys and values) that are associated with the configuration set.
-
#tracking_options ⇒ Types::TrackingOptions
An object that defines the open and click tracking options for emails that you send using the configuration set.
-
#vdm_options ⇒ Types::VdmOptions
An object that contains information about the VDM preferences for your configuration set.
Instance Attribute Details
#archiving_options ⇒ Types::ArchivingOptions
An object that defines the MailManager archive where sent emails are archived that you send using the configuration set.
3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3579 class GetConfigurationSetResponse < Struct.new( :configuration_set_name, :tracking_options, :delivery_options, :reputation_options, :sending_options, :tags, :suppression_options, :vdm_options, :archiving_options) SENSITIVE = [] include Aws::Structure end |
#configuration_set_name ⇒ String
The name of the configuration set.
3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3579 class GetConfigurationSetResponse < Struct.new( :configuration_set_name, :tracking_options, :delivery_options, :reputation_options, :sending_options, :tags, :suppression_options, :vdm_options, :archiving_options) SENSITIVE = [] include Aws::Structure end |
#delivery_options ⇒ Types::DeliveryOptions
An object that defines the dedicated IP pool that is used to send emails that you send using the configuration set.
3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3579 class GetConfigurationSetResponse < Struct.new( :configuration_set_name, :tracking_options, :delivery_options, :reputation_options, :sending_options, :tags, :suppression_options, :vdm_options, :archiving_options) SENSITIVE = [] include Aws::Structure end |
#reputation_options ⇒ Types::ReputationOptions
An object that defines whether or not Amazon SES collects reputation metrics for the emails that you send that use the configuration set.
3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3579 class GetConfigurationSetResponse < Struct.new( :configuration_set_name, :tracking_options, :delivery_options, :reputation_options, :sending_options, :tags, :suppression_options, :vdm_options, :archiving_options) SENSITIVE = [] include Aws::Structure end |
#sending_options ⇒ Types::SendingOptions
An object that defines whether or not Amazon SES can send email that you send using the configuration set.
3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3579 class GetConfigurationSetResponse < Struct.new( :configuration_set_name, :tracking_options, :delivery_options, :reputation_options, :sending_options, :tags, :suppression_options, :vdm_options, :archiving_options) SENSITIVE = [] include Aws::Structure end |
#suppression_options ⇒ Types::SuppressionOptions
An object that contains information about the suppression list preferences for your account or for a specific tenant.
3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3579 class GetConfigurationSetResponse < Struct.new( :configuration_set_name, :tracking_options, :delivery_options, :reputation_options, :sending_options, :tags, :suppression_options, :vdm_options, :archiving_options) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of objects that define the tags (keys and values) that are associated with the configuration set.
3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3579 class GetConfigurationSetResponse < Struct.new( :configuration_set_name, :tracking_options, :delivery_options, :reputation_options, :sending_options, :tags, :suppression_options, :vdm_options, :archiving_options) SENSITIVE = [] include Aws::Structure end |
#tracking_options ⇒ Types::TrackingOptions
An object that defines the open and click tracking options for emails that you send using the configuration set.
3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3579 class GetConfigurationSetResponse < Struct.new( :configuration_set_name, :tracking_options, :delivery_options, :reputation_options, :sending_options, :tags, :suppression_options, :vdm_options, :archiving_options) SENSITIVE = [] include Aws::Structure end |
#vdm_options ⇒ Types::VdmOptions
An object that contains information about the VDM preferences for your configuration set.
3579 3580 3581 3582 3583 3584 3585 3586 3587 3588 3589 3590 3591 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3579 class GetConfigurationSetResponse < Struct.new( :configuration_set_name, :tracking_options, :delivery_options, :reputation_options, :sending_options, :tags, :suppression_options, :vdm_options, :archiving_options) SENSITIVE = [] include Aws::Structure end |