Class: Aws::SESV2::Types::GetCustomVerificationEmailTemplateRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::GetCustomVerificationEmailTemplateRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Represents a request to retrieve an existing custom verification email template.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#template_name ⇒ String
The name of the custom verification email template that you want to retrieve.
Instance Attribute Details
#template_name ⇒ String
The name of the custom verification email template that you want to retrieve.
3720 3721 3722 3723 3724 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3720 class GetCustomVerificationEmailTemplateRequest < Struct.new( :template_name) SENSITIVE = [] include Aws::Structure end |