Class: Aws::SESV2::Types::GetCustomVerificationEmailTemplateResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::GetCustomVerificationEmailTemplateResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
The following elements are returned by the service.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#failure_redirection_url ⇒ String
The URL that the recipient of the verification email is sent to if his or her address is not successfully verified.
-
#from_email_address ⇒ String
The email address that the custom verification email is sent from.
-
#success_redirection_url ⇒ String
The URL that the recipient of the verification email is sent to if his or her address is successfully verified.
-
#tags ⇒ Array<Types::Tag>
An array of objects that define the tags (keys and values) that are associated with the custom verification email template.
-
#template_content ⇒ String
The content of the custom verification email.
-
#template_name ⇒ String
The name of the custom verification email template.
-
#template_subject ⇒ String
The subject line of the custom verification email.
Instance Attribute Details
#failure_redirection_url ⇒ String
The URL that the recipient of the verification email is sent to if his or her address is not successfully verified.
3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3761 class GetCustomVerificationEmailTemplateResponse < Struct.new( :template_name, :from_email_address, :template_subject, :template_content, :tags, :success_redirection_url, :failure_redirection_url) SENSITIVE = [] include Aws::Structure end |
#from_email_address ⇒ String
The email address that the custom verification email is sent from.
3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3761 class GetCustomVerificationEmailTemplateResponse < Struct.new( :template_name, :from_email_address, :template_subject, :template_content, :tags, :success_redirection_url, :failure_redirection_url) SENSITIVE = [] include Aws::Structure end |
#success_redirection_url ⇒ String
The URL that the recipient of the verification email is sent to if his or her address is successfully verified.
3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3761 class GetCustomVerificationEmailTemplateResponse < Struct.new( :template_name, :from_email_address, :template_subject, :template_content, :tags, :success_redirection_url, :failure_redirection_url) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of objects that define the tags (keys and values) that are associated with the custom verification email template.
3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3761 class GetCustomVerificationEmailTemplateResponse < Struct.new( :template_name, :from_email_address, :template_subject, :template_content, :tags, :success_redirection_url, :failure_redirection_url) SENSITIVE = [] include Aws::Structure end |
#template_content ⇒ String
The content of the custom verification email.
3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3761 class GetCustomVerificationEmailTemplateResponse < Struct.new( :template_name, :from_email_address, :template_subject, :template_content, :tags, :success_redirection_url, :failure_redirection_url) SENSITIVE = [] include Aws::Structure end |
#template_name ⇒ String
The name of the custom verification email template.
3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3761 class GetCustomVerificationEmailTemplateResponse < Struct.new( :template_name, :from_email_address, :template_subject, :template_content, :tags, :success_redirection_url, :failure_redirection_url) SENSITIVE = [] include Aws::Structure end |
#template_subject ⇒ String
The subject line of the custom verification email.
3761 3762 3763 3764 3765 3766 3767 3768 3769 3770 3771 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3761 class GetCustomVerificationEmailTemplateResponse < Struct.new( :template_name, :from_email_address, :template_subject, :template_content, :tags, :success_redirection_url, :failure_redirection_url) SENSITIVE = [] include Aws::Structure end |