Class: Aws::SESV2::Types::GetDedicatedIpsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::GetDedicatedIpsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Information about the dedicated IP addresses that are associated with your Amazon Web Services account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dedicated_ips ⇒ Array<Types::DedicatedIp>
A list of dedicated IP addresses that are associated with your Amazon Web Services account.
-
#next_token ⇒ String
A token that indicates that there are additional dedicated IP addresses to list.
Instance Attribute Details
#dedicated_ips ⇒ Array<Types::DedicatedIp>
A list of dedicated IP addresses that are associated with your Amazon Web Services account.
3920 3921 3922 3923 3924 3925 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3920 class GetDedicatedIpsResponse < Struct.new( :dedicated_ips, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates that there are additional dedicated IP
addresses to list. To view additional addresses, issue another
request to GetDedicatedIps, passing this token in the NextToken
parameter.
3920 3921 3922 3923 3924 3925 |
# File 'lib/aws-sdk-sesv2/types.rb', line 3920 class GetDedicatedIpsResponse < Struct.new( :dedicated_ips, :next_token) SENSITIVE = [] include Aws::Structure end |