Class: Aws::SESV2::Types::GetDeliverabilityDashboardOptionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

An object that shows the status of the Deliverability dashboard.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#account_statusString

The current status of your Deliverability dashboard subscription. If this value is PENDING_EXPIRATION, your subscription is scheduled to expire at the end of the current calendar month.

Returns:

  • (String)


3963
3964
3965
3966
3967
3968
3969
3970
3971
# File 'lib/aws-sdk-sesv2/types.rb', line 3963

class GetDeliverabilityDashboardOptionsResponse < Struct.new(
  :dashboard_enabled,
  :subscription_expiry_date,
  :account_status,
  :active_subscribed_domains,
  :pending_expiration_subscribed_domains)
  SENSITIVE = []
  include Aws::Structure
end

#active_subscribed_domainsArray<Types::DomainDeliverabilityTrackingOption>

An array of objects, one for each verified domain that you use to send email and currently has an active Deliverability dashboard subscription that isn’t scheduled to expire at the end of the current calendar month.



3963
3964
3965
3966
3967
3968
3969
3970
3971
# File 'lib/aws-sdk-sesv2/types.rb', line 3963

class GetDeliverabilityDashboardOptionsResponse < Struct.new(
  :dashboard_enabled,
  :subscription_expiry_date,
  :account_status,
  :active_subscribed_domains,
  :pending_expiration_subscribed_domains)
  SENSITIVE = []
  include Aws::Structure
end

#dashboard_enabledBoolean

Specifies whether the Deliverability dashboard is enabled. If this value is true, the dashboard is enabled.

Returns:

  • (Boolean)


3963
3964
3965
3966
3967
3968
3969
3970
3971
# File 'lib/aws-sdk-sesv2/types.rb', line 3963

class GetDeliverabilityDashboardOptionsResponse < Struct.new(
  :dashboard_enabled,
  :subscription_expiry_date,
  :account_status,
  :active_subscribed_domains,
  :pending_expiration_subscribed_domains)
  SENSITIVE = []
  include Aws::Structure
end

#pending_expiration_subscribed_domainsArray<Types::DomainDeliverabilityTrackingOption>

An array of objects, one for each verified domain that you use to send email and currently has an active Deliverability dashboard subscription that's scheduled to expire at the end of the current calendar month.



3963
3964
3965
3966
3967
3968
3969
3970
3971
# File 'lib/aws-sdk-sesv2/types.rb', line 3963

class GetDeliverabilityDashboardOptionsResponse < Struct.new(
  :dashboard_enabled,
  :subscription_expiry_date,
  :account_status,
  :active_subscribed_domains,
  :pending_expiration_subscribed_domains)
  SENSITIVE = []
  include Aws::Structure
end

#subscription_expiry_dateTime

The date when your current subscription to the Deliverability dashboard is scheduled to expire, if your subscription is scheduled to expire at the end of the current calendar month. This value is null if you have an active subscription that isn’t due to expire at the end of the month.

Returns:

  • (Time)


3963
3964
3965
3966
3967
3968
3969
3970
3971
# File 'lib/aws-sdk-sesv2/types.rb', line 3963

class GetDeliverabilityDashboardOptionsResponse < Struct.new(
  :dashboard_enabled,
  :subscription_expiry_date,
  :account_status,
  :active_subscribed_domains,
  :pending_expiration_subscribed_domains)
  SENSITIVE = []
  include Aws::Structure
end