Class: Aws::SESV2::Types::GetDomainStatisticsReportRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

A request to obtain deliverability metrics for a domain.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domainString

The domain that you want to obtain deliverability metrics for.

Returns:

  • (String)


4196
4197
4198
4199
4200
4201
4202
# File 'lib/aws-sdk-sesv2/types.rb', line 4196

class GetDomainStatisticsReportRequest < Struct.new(
  :domain,
  :start_date,
  :end_date)
  SENSITIVE = []
  include Aws::Structure
end

#end_dateTime

The last day (in Unix time) that you want to obtain domain deliverability metrics for. The EndDate that you specify has to be less than or equal to 30 days after the StartDate.

Returns:

  • (Time)


4196
4197
4198
4199
4200
4201
4202
# File 'lib/aws-sdk-sesv2/types.rb', line 4196

class GetDomainStatisticsReportRequest < Struct.new(
  :domain,
  :start_date,
  :end_date)
  SENSITIVE = []
  include Aws::Structure
end

#start_dateTime

The first day (in Unix time) that you want to obtain domain deliverability metrics for.

Returns:

  • (Time)


4196
4197
4198
4199
4200
4201
4202
# File 'lib/aws-sdk-sesv2/types.rb', line 4196

class GetDomainStatisticsReportRequest < Struct.new(
  :domain,
  :start_date,
  :end_date)
  SENSITIVE = []
  include Aws::Structure
end