Class: Aws::SESV2::Types::GetEmailTemplateResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

The following element is returned by the service.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#tagsArray<Types::Tag>

An array of objects that define the tags (keys and values) that are associated with the email template.

Returns:



4290
4291
4292
4293
4294
4295
4296
# File 'lib/aws-sdk-sesv2/types.rb', line 4290

class GetEmailTemplateResponse < Struct.new(
  :template_name,
  :template_content,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#template_contentTypes::EmailTemplateContent

The content of the email template, composed of a subject line, an HTML part, and a text-only part.



4290
4291
4292
4293
4294
4295
4296
# File 'lib/aws-sdk-sesv2/types.rb', line 4290

class GetEmailTemplateResponse < Struct.new(
  :template_name,
  :template_content,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#template_nameString

The name of the template.

Returns:

  • (String)


4290
4291
4292
4293
4294
4295
4296
# File 'lib/aws-sdk-sesv2/types.rb', line 4290

class GetEmailTemplateResponse < Struct.new(
  :template_name,
  :template_content,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end