Class: Aws::SESV2::Types::GetSuppressedDestinationRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

A request to retrieve information about an email address that’s on the suppression list for your account or for a specific tenant.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#email_addressString

The email address that’s on the suppression list for your account or for the specified tenant.

Returns:

  • (String)


4612
4613
4614
4615
4616
4617
# File 'lib/aws-sdk-sesv2/types.rb', line 4612

class GetSuppressedDestinationRequest < Struct.new(
  :email_address,
  :tenant_name)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_nameString

The name of the tenant whose suppression list you want to query. If you omit this parameter, the operation targets the account-level suppression list.

Returns:

  • (String)


4612
4613
4614
4615
4616
4617
# File 'lib/aws-sdk-sesv2/types.rb', line 4612

class GetSuppressedDestinationRequest < Struct.new(
  :email_address,
  :tenant_name)
  SENSITIVE = []
  include Aws::Structure
end