Class: Aws::SESV2::Types::KinesisFirehoseDestination
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::KinesisFirehoseDestination
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
An object that defines an Amazon Kinesis Data Firehose destination for email events. You can use Amazon Kinesis Data Firehose to stream data to other services, such as Amazon S3 and Amazon Redshift.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#delivery_stream_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Kinesis Data Firehose stream that the Amazon SES API v2 sends email events to.
-
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that the Amazon SES API v2 uses to send email events to the Amazon Kinesis Data Firehose stream.
Instance Attribute Details
#delivery_stream_arn ⇒ String
The Amazon Resource Name (ARN) of the Amazon Kinesis Data Firehose stream that the Amazon SES API v2 sends email events to.
4998 4999 5000 5001 5002 5003 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4998 class KinesisFirehoseDestination < Struct.new( :iam_role_arn, :delivery_stream_arn) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that the Amazon SES API v2 uses to send email events to the Amazon Kinesis Data Firehose stream.
4998 4999 5000 5001 5002 5003 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4998 class KinesisFirehoseDestination < Struct.new( :iam_role_arn, :delivery_stream_arn) SENSITIVE = [] include Aws::Structure end |