Class: Aws::SESV2::Types::ListConfigurationSetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListConfigurationSetsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to obtain a list of configuration sets for your Amazon SES account in the current Amazon Web Services Region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token returned from a previous call to
ListConfigurationSetsto indicate the position in the list of configuration sets. -
#page_size ⇒ Integer
The number of results to show in a single call to
ListConfigurationSets.
Instance Attribute Details
#next_token ⇒ String
A token returned from a previous call to ListConfigurationSets to indicate the position in the list of configuration sets.
4973 4974 4975 4976 4977 4978 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4973 class ListConfigurationSetsRequest < Struct.new( :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The number of results to show in a single call to ListConfigurationSets. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results.
4973 4974 4975 4976 4977 4978 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4973 class ListConfigurationSetsRequest < Struct.new( :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |