Class: Aws::SESV2::Types::ListContactListsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListContactListsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A string token indicating that there might be additional contact lists available to be listed.
-
#page_size ⇒ Integer
Maximum number of contact lists to return at once.
Instance Attribute Details
#next_token ⇒ String
A string token indicating that there might be additional contact lists available to be listed. Use the token provided in the Response to use in the subsequent call to ListContactLists with the same parameters to retrieve the next page of contact lists.
5221 5222 5223 5224 5225 5226 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5221 class ListContactListsRequest < Struct.new( :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
Maximum number of contact lists to return at once. Use this
parameter to paginate results. If additional contact lists exist
beyond the specified limit, the NextToken element is sent in the
response. Use the NextToken value in subsequent requests to
retrieve additional lists.
5221 5222 5223 5224 5225 5226 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5221 class ListContactListsRequest < Struct.new( :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |