Class: Aws::SESV2::Types::ListContactsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#contactsArray<Types::Contact>

The contacts present in a specific contact list.

Returns:



5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-sesv2/types.rb', line 5115

class ListContactsResponse < Struct.new(
  :contacts,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A string token indicating that there might be additional contacts available to be listed. Copy this token to a subsequent call to ListContacts with the same parameters to retrieve the next page of contacts.

Returns:

  • (String)


5115
5116
5117
5118
5119
5120
# File 'lib/aws-sdk-sesv2/types.rb', line 5115

class ListContactsResponse < Struct.new(
  :contacts,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end