Class: Aws::SESV2::Types::ListDedicatedIpPoolsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListDedicatedIpPoolsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to obtain a list of dedicated IP pools.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token returned from a previous call to
ListDedicatedIpPoolsto indicate the position in the list of dedicated IP pools. -
#page_size ⇒ Integer
The number of results to show in a single call to
ListDedicatedIpPools.
Instance Attribute Details
#next_token ⇒ String
A token returned from a previous call to ListDedicatedIpPools to
indicate the position in the list of dedicated IP pools.
5390 5391 5392 5393 5394 5395 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5390 class ListDedicatedIpPoolsRequest < Struct.new( :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The number of results to show in a single call to
ListDedicatedIpPools. If the number of results is larger than the
number you specified in this parameter, then the response includes a
NextToken element, which you can use to obtain additional results.
5390 5391 5392 5393 5394 5395 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5390 class ListDedicatedIpPoolsRequest < Struct.new( :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |