Class: Aws::SESV2::Types::ListDedicatedIpPoolsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListDedicatedIpPoolsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A list of dedicated IP pools.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dedicated_ip_pools ⇒ Array<String>
A list of all of the dedicated IP pools that are associated with your Amazon Web Services account in the current Region.
-
#next_token ⇒ String
A token that indicates that there are additional IP pools to list.
Instance Attribute Details
#dedicated_ip_pools ⇒ Array<String>
A list of all of the dedicated IP pools that are associated with your Amazon Web Services account in the current Region.
5413 5414 5415 5416 5417 5418 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5413 class ListDedicatedIpPoolsResponse < Struct.new( :dedicated_ip_pools, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates that there are additional IP pools to list.
To view additional IP pools, issue another request to
ListDedicatedIpPools, passing this token in the NextToken
parameter.
5413 5414 5415 5416 5417 5418 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5413 class ListDedicatedIpPoolsResponse < Struct.new( :dedicated_ip_pools, :next_token) SENSITIVE = [] include Aws::Structure end |