Class: Aws::SESV2::Types::ListDomainDeliverabilityCampaignsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

Retrieve deliverability data for all the campaigns that used a specific domain to send email during a specified time range. This data is available for a domain only if you enabled the Deliverability dashboard.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_dateTime

The last day that you want to obtain deliverability data for. This value has to be less than or equal to 30 days after the value of the StartDate parameter.

Returns:



5510
5511
5512
5513
5514
5515
5516
5517
5518
# File 'lib/aws-sdk-sesv2/types.rb', line 5510

class ListDomainDeliverabilityCampaignsRequest < Struct.new(
  :start_date,
  :end_date,
  :subscribed_domain,
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token that’s returned from a previous call to the ListDomainDeliverabilityCampaigns operation. This token indicates the position of a campaign in the list of campaigns.

Returns:



5510
5511
5512
5513
5514
5515
5516
5517
5518
# File 'lib/aws-sdk-sesv2/types.rb', line 5510

class ListDomainDeliverabilityCampaignsRequest < Struct.new(
  :start_date,
  :end_date,
  :subscribed_domain,
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end

#page_sizeInteger

The maximum number of results to include in response to a single call to the ListDomainDeliverabilityCampaigns operation. If the number of results is larger than the number that you specify in this parameter, the response includes a NextToken element, which you can use to obtain additional results.

Returns:



5510
5511
5512
5513
5514
5515
5516
5517
5518
# File 'lib/aws-sdk-sesv2/types.rb', line 5510

class ListDomainDeliverabilityCampaignsRequest < Struct.new(
  :start_date,
  :end_date,
  :subscribed_domain,
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end

#start_dateTime

The first day that you want to obtain deliverability data for.

Returns:



5510
5511
5512
5513
5514
5515
5516
5517
5518
# File 'lib/aws-sdk-sesv2/types.rb', line 5510

class ListDomainDeliverabilityCampaignsRequest < Struct.new(
  :start_date,
  :end_date,
  :subscribed_domain,
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end

#subscribed_domainString

The domain to obtain deliverability data for.

Returns:



5510
5511
5512
5513
5514
5515
5516
5517
5518
# File 'lib/aws-sdk-sesv2/types.rb', line 5510

class ListDomainDeliverabilityCampaignsRequest < Struct.new(
  :start_date,
  :end_date,
  :subscribed_domain,
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end