Class: Aws::SESV2::Types::ListDomainDeliverabilityCampaignsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListDomainDeliverabilityCampaignsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
An array of objects that provide deliverability data for all the campaigns that used a specific domain to send email during a specified time range. This data is available for a domain only if you enabled the Deliverability dashboard for the domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain_deliverability_campaigns ⇒ Array<Types::DomainDeliverabilityCampaign>
An array of responses, one for each campaign that used the domain to send email during the specified time range.
-
#next_token ⇒ String
A token that’s returned from a previous call to the
ListDomainDeliverabilityCampaignsoperation.
Instance Attribute Details
#domain_deliverability_campaigns ⇒ Array<Types::DomainDeliverabilityCampaign>
An array of responses, one for each campaign that used the domain to send email during the specified time range.
5538 5539 5540 5541 5542 5543 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5538 class ListDomainDeliverabilityCampaignsResponse < Struct.new( :domain_deliverability_campaigns, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that’s returned from a previous call to the
ListDomainDeliverabilityCampaigns operation. This token indicates
the position of the campaign in the list of campaigns.
5538 5539 5540 5541 5542 5543 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5538 class ListDomainDeliverabilityCampaignsResponse < Struct.new( :domain_deliverability_campaigns, :next_token) SENSITIVE = [] include Aws::Structure end |