Class: Aws::SESV2::Types::ListRecommendationsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

Contains the response to your request to retrieve the list of recommendations for your account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A string token indicating that there might be additional recommendations available to be listed. Use the token provided in the ListRecommendationsResponse to use in the subsequent call to ListRecommendations with the same parameters to retrieve the next page of recommendations.

Returns:

  • (String)


5945
5946
5947
5948
5949
5950
# File 'lib/aws-sdk-sesv2/types.rb', line 5945

class ListRecommendationsResponse < Struct.new(
  :recommendations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#recommendationsArray<Types::Recommendation>

The recommendations applicable to your account.

Returns:



5945
5946
5947
5948
5949
5950
# File 'lib/aws-sdk-sesv2/types.rb', line 5945

class ListRecommendationsResponse < Struct.new(
  :recommendations,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end