Class: Aws::SESV2::Types::ListReputationEntitiesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListReputationEntitiesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Represents a request to list reputation entities with optional filtering.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Hash<String,String>
An object that contains filters to apply when listing reputation entities.
-
#next_token ⇒ String
A token returned from a previous call to
ListReputationEntitiesto indicate the position in the list of reputation entities. -
#page_size ⇒ Integer
The number of results to show in a single call to
ListReputationEntities.
Instance Attribute Details
#filter ⇒ Hash<String,String>
An object that contains filters to apply when listing reputation entities. You can filter by entity type, reputation impact, sending status, or entity reference prefix.
5976 5977 5978 5979 5980 5981 5982 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5976 class ListReputationEntitiesRequest < Struct.new( :filter, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token returned from a previous call to ListReputationEntities to
indicate the position in the list of reputation entities.
5976 5977 5978 5979 5980 5981 5982 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5976 class ListReputationEntitiesRequest < Struct.new( :filter, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The number of results to show in a single call to
ListReputationEntities. If the number of results is larger than
the number you specified in this parameter, then the response
includes a NextToken element, which you can use to obtain
additional results.
5976 5977 5978 5979 5980 5981 5982 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5976 class ListReputationEntitiesRequest < Struct.new( :filter, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |