Class: Aws::SESV2::Types::ListResourceTenantsResponse

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

Information about tenants associated with a specific resource.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A token that indicates that there are additional tenants to list. To view additional tenants, issue another request to ListResourceTenants, and pass this token in the NextToken parameter.

Returns:

  • (String)


6053
6054
6055
6056
6057
6058
# File 'lib/aws-sdk-sesv2/types.rb', line 6053

class ListResourceTenantsResponse < Struct.new(
  :resource_tenants,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#resource_tenantsArray<Types::ResourceTenantMetadata>

An array that contains information about each tenant associated with the resource.

Returns:



6053
6054
6055
6056
6057
6058
# File 'lib/aws-sdk-sesv2/types.rb', line 6053

class ListResourceTenantsResponse < Struct.new(
  :resource_tenants,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end