Class: Aws::SESV2::Types::ListSuppressedDestinationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

A request to obtain a list of email destinations that are on the suppression list for your account or for a specific tenant.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#end_dateTime

Used to filter the list of suppressed email destinations so that it only includes addresses that were added to the list before a specific date.

Returns:

  • (Time)


6102
6103
6104
6105
6106
6107
6108
6109
6110
6111
# File 'lib/aws-sdk-sesv2/types.rb', line 6102

class ListSuppressedDestinationsRequest < Struct.new(
  :tenant_name,
  :reasons,
  :start_date,
  :end_date,
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token returned from a previous call to ListSuppressedDestinations to indicate the position in the list of suppressed email addresses.

Returns:

  • (String)


6102
6103
6104
6105
6106
6107
6108
6109
6110
6111
# File 'lib/aws-sdk-sesv2/types.rb', line 6102

class ListSuppressedDestinationsRequest < Struct.new(
  :tenant_name,
  :reasons,
  :start_date,
  :end_date,
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end

#page_sizeInteger

The number of results to show in a single call to ListSuppressedDestinations. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results.

Returns:

  • (Integer)


6102
6103
6104
6105
6106
6107
6108
6109
6110
6111
# File 'lib/aws-sdk-sesv2/types.rb', line 6102

class ListSuppressedDestinationsRequest < Struct.new(
  :tenant_name,
  :reasons,
  :start_date,
  :end_date,
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end

#reasonsArray<String>

The factors that caused the email address to be added to the suppression list for your account or for a specific tenant.

Returns:

  • (Array<String>)


6102
6103
6104
6105
6106
6107
6108
6109
6110
6111
# File 'lib/aws-sdk-sesv2/types.rb', line 6102

class ListSuppressedDestinationsRequest < Struct.new(
  :tenant_name,
  :reasons,
  :start_date,
  :end_date,
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end

#start_dateTime

Used to filter the list of suppressed email destinations so that it only includes addresses that were added to the list after a specific date.

Returns:

  • (Time)


6102
6103
6104
6105
6106
6107
6108
6109
6110
6111
# File 'lib/aws-sdk-sesv2/types.rb', line 6102

class ListSuppressedDestinationsRequest < Struct.new(
  :tenant_name,
  :reasons,
  :start_date,
  :end_date,
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_nameString

The name of the tenant whose suppression list you want to retrieve. If you omit this parameter, the operation targets the account-level suppression list.

Returns:

  • (String)


6102
6103
6104
6105
6106
6107
6108
6109
6110
6111
# File 'lib/aws-sdk-sesv2/types.rb', line 6102

class ListSuppressedDestinationsRequest < Struct.new(
  :tenant_name,
  :reasons,
  :start_date,
  :end_date,
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end