Class: Aws::SESV2::Types::ListTenantResourcesRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

Represents a request to list resources associated with a specific tenant.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filterHash<String,String>

A map of filter keys and values for filtering the list of tenant resources. Currently, the only supported filter key is RESOURCE_TYPE.

Returns:

  • (Hash<String,String>)


6191
6192
6193
6194
6195
6196
6197
6198
# File 'lib/aws-sdk-sesv2/types.rb', line 6191

class ListTenantResourcesRequest < Struct.new(
  :tenant_name,
  :filter,
  :page_size,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

A token returned from a previous call to ListTenantResources to indicate the position in the list of tenant resources.

Returns:

  • (String)


6191
6192
6193
6194
6195
6196
6197
6198
# File 'lib/aws-sdk-sesv2/types.rb', line 6191

class ListTenantResourcesRequest < Struct.new(
  :tenant_name,
  :filter,
  :page_size,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#page_sizeInteger

The number of results to show in a single call to ListTenantResources. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results.

Returns:

  • (Integer)


6191
6192
6193
6194
6195
6196
6197
6198
# File 'lib/aws-sdk-sesv2/types.rb', line 6191

class ListTenantResourcesRequest < Struct.new(
  :tenant_name,
  :filter,
  :page_size,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_nameString

The name of the tenant to list resources for.

Returns:

  • (String)


6191
6192
6193
6194
6195
6196
6197
6198
# File 'lib/aws-sdk-sesv2/types.rb', line 6191

class ListTenantResourcesRequest < Struct.new(
  :tenant_name,
  :filter,
  :page_size,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end