Class: Aws::SESV2::Types::ListTenantResourcesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListTenantResourcesResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Information about resources associated with a specific tenant.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token that indicates that there are additional resources to list.
-
#tenant_resources ⇒ Array<Types::TenantResource>
An array that contains information about each resource associated with the tenant.
Instance Attribute Details
#next_token ⇒ String
A token that indicates that there are additional resources to list.
To view additional resources, issue another request to
ListTenantResources, and pass this token in the NextToken
parameter.
6216 6217 6218 6219 6220 6221 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6216 class ListTenantResourcesResponse < Struct.new( :tenant_resources, :next_token) SENSITIVE = [] include Aws::Structure end |
#tenant_resources ⇒ Array<Types::TenantResource>
An array that contains information about each resource associated with the tenant.
6216 6217 6218 6219 6220 6221 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6216 class ListTenantResourcesResponse < Struct.new( :tenant_resources, :next_token) SENSITIVE = [] include Aws::Structure end |