Class: Aws::SESV2::Types::ListTenantsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListTenantsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Represents a request to list all tenants associated with your account in the current Amazon Web Services Region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token returned from a previous call to
ListTenantsto indicate the position in the list of tenants. -
#page_size ⇒ Integer
The number of results to show in a single call to
ListTenants.
Instance Attribute Details
#next_token ⇒ String
A token returned from a previous call to ListTenants to indicate
the position in the list of tenants.
6240 6241 6242 6243 6244 6245 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6240 class ListTenantsRequest < Struct.new( :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The number of results to show in a single call to ListTenants. If
the number of results is larger than the number you specified in
this parameter, then the response includes a NextToken element,
which you can use to obtain additional results.
6240 6241 6242 6243 6244 6245 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6240 class ListTenantsRequest < Struct.new( :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |