Class: Aws::SESV2::Types::ListTenantsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListTenantsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Information about tenants associated with your account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token that indicates that there are additional tenants to list.
-
#tenants ⇒ Array<Types::TenantInfo>
An array that contains basic information about each tenant.
Instance Attribute Details
#next_token ⇒ String
A token that indicates that there are additional tenants to list. To
view additional tenants, issue another request to ListTenants, and
pass this token in the NextToken parameter.
6261 6262 6263 6264 6265 6266 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6261 class ListTenantsResponse < Struct.new( :tenants, :next_token) SENSITIVE = [] include Aws::Structure end |
#tenants ⇒ Array<Types::TenantInfo>
An array that contains basic information about each tenant.
6261 6262 6263 6264 6265 6266 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6261 class ListTenantsResponse < Struct.new( :tenants, :next_token) SENSITIVE = [] include Aws::Structure end |