Class: Aws::SESV2::Types::PricingAttributes

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

The pricing attributes that apply to your Amazon SES account, including the currently active pricing plan and any scheduled change.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#current_planString

The pricing plan that is currently active on your Amazon SES account.

Returns:

  • (String)


6627
6628
6629
6630
6631
6632
# File 'lib/aws-sdk-sesv2/types.rb', line 6627

class PricingAttributes < Struct.new(
  :current_plan,
  :next_plan)
  SENSITIVE = []
  include Aws::Structure
end

#next_planString

The pricing plan that will become active at the start of the next monthly cycle, if a scheduled change has been requested. This field is empty when no scheduled change is pending.

Returns:

  • (String)


6627
6628
6629
6630
6631
6632
# File 'lib/aws-sdk-sesv2/types.rb', line 6627

class PricingAttributes < Struct.new(
  :current_plan,
  :next_plan)
  SENSITIVE = []
  include Aws::Structure
end