Class: Aws::SESV2::Types::PutAccountPricingAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

A request to set the pricing plan for your Amazon SES account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#planString

The pricing plan to apply to your Amazon SES account. For details about each plan, see Amazon SES Pricing. Can be one of the following:

  • NONE

  • ESSENTIALS

  • PRO

  • ENTERPRISE

Returns:

  • (String)


6739
6740
6741
6742
6743
# File 'lib/aws-sdk-sesv2/types.rb', line 6739

class PutAccountPricingAttributesRequest < Struct.new(
  :plan)
  SENSITIVE = []
  include Aws::Structure
end