Class: Aws::SESV2::Types::PutAccountSendingAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

A request to change the ability of your account to send email.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#sending_enabledBoolean

Enables or disables your account's ability to send email. Set to true to enable email sending, or set to false to disable email sending.

If Amazon Web Services paused your account's ability to send email, you can't use this operation to resume your account's ability to send email.

Returns:

  • (Boolean)


6727
6728
6729
6730
6731
# File 'lib/aws-sdk-sesv2/types.rb', line 6727

class PutAccountSendingAttributesRequest < Struct.new(
  :sending_enabled)
  SENSITIVE = []
  include Aws::Structure
end