Class: Aws::SESV2::Types::PutConfigurationSetDeliveryOptionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

A request to associate a configuration set with a dedicated IP pool.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_set_nameString

The name of the configuration set to associate with a dedicated IP pool.

Returns:

  • (String)


6788
6789
6790
6791
6792
6793
6794
6795
# File 'lib/aws-sdk-sesv2/types.rb', line 6788

class PutConfigurationSetDeliveryOptionsRequest < Struct.new(
  :configuration_set_name,
  :tls_policy,
  :sending_pool_name,
  :max_delivery_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#max_delivery_secondsInteger

The maximum amount of time, in seconds, that Amazon SES API v2 will attempt delivery of email. If specified, the value must greater than or equal to 300 seconds (5 minutes) and less than or equal to 50400 seconds (840 minutes).

Returns:

  • (Integer)


6788
6789
6790
6791
6792
6793
6794
6795
# File 'lib/aws-sdk-sesv2/types.rb', line 6788

class PutConfigurationSetDeliveryOptionsRequest < Struct.new(
  :configuration_set_name,
  :tls_policy,
  :sending_pool_name,
  :max_delivery_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#sending_pool_nameString

The name of the dedicated IP pool to associate with the configuration set.

Returns:

  • (String)


6788
6789
6790
6791
6792
6793
6794
6795
# File 'lib/aws-sdk-sesv2/types.rb', line 6788

class PutConfigurationSetDeliveryOptionsRequest < Struct.new(
  :configuration_set_name,
  :tls_policy,
  :sending_pool_name,
  :max_delivery_seconds)
  SENSITIVE = []
  include Aws::Structure
end

#tls_policyString

Specifies whether messages that use the configuration set are required to use Transport Layer Security (TLS). If the value is ‘Require`, messages are only delivered if a TLS connection can be established. If the value is `Optional`, messages can be delivered in plain text if a TLS connection can’t be established.

Returns:

  • (String)


6788
6789
6790
6791
6792
6793
6794
6795
# File 'lib/aws-sdk-sesv2/types.rb', line 6788

class PutConfigurationSetDeliveryOptionsRequest < Struct.new(
  :configuration_set_name,
  :tls_policy,
  :sending_pool_name,
  :max_delivery_seconds)
  SENSITIVE = []
  include Aws::Structure
end