Class: Aws::SESV2::Types::PutConfigurationSetSendingOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::PutConfigurationSetSendingOptionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to enable or disable the ability of Amazon SES to send emails that use a specific configuration set.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_set_name ⇒ String
The name of the configuration set to enable or disable email sending for.
-
#sending_enabled ⇒ Boolean
If
true, email sending is enabled for the configuration set.
Instance Attribute Details
#configuration_set_name ⇒ String
The name of the configuration set to enable or disable email sending for.
6913 6914 6915 6916 6917 6918 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6913 class PutConfigurationSetSendingOptionsRequest < Struct.new( :configuration_set_name, :sending_enabled) SENSITIVE = [] include Aws::Structure end |
#sending_enabled ⇒ Boolean
If true, email sending is enabled for the configuration set. If
false, email sending is disabled for the configuration set.
6913 6914 6915 6916 6917 6918 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6913 class PutConfigurationSetSendingOptionsRequest < Struct.new( :configuration_set_name, :sending_enabled) SENSITIVE = [] include Aws::Structure end |