Class: Aws::SESV2::Types::PutEmailIdentityDkimAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::PutEmailIdentityDkimAttributesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to enable or disable DKIM signing of email that you send from an email identity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#email_identity ⇒ String
The email identity.
-
#signing_enabled ⇒ Boolean
Sets the DKIM signing configuration for the identity.
Instance Attribute Details
#email_identity ⇒ String
The email identity.
7240 7241 7242 7243 7244 7245 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7240 class PutEmailIdentityDkimAttributesRequest < Struct.new( :email_identity, :signing_enabled) SENSITIVE = [] include Aws::Structure end |
#signing_enabled ⇒ Boolean
Sets the DKIM signing configuration for the identity.
When you set this value true, then the messages that are sent from
the identity are signed using DKIM. If you set this value to
false, your messages are sent without DKIM signing.
7240 7241 7242 7243 7244 7245 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7240 class PutEmailIdentityDkimAttributesRequest < Struct.new( :email_identity, :signing_enabled) SENSITIVE = [] include Aws::Structure end |