Class: Aws::SESV2::Types::PutEmailIdentityFeedbackAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::PutEmailIdentityFeedbackAttributesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to set the attributes that control how bounce and complaint events are processed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#email_forwarding_enabled ⇒ Boolean
Sets the feedback forwarding configuration for the identity.
-
#email_identity ⇒ String
The email identity.
Instance Attribute Details
#email_forwarding_enabled ⇒ Boolean
Sets the feedback forwarding configuration for the identity.
If the value is true, you receive email notifications when bounce or complaint events occur. These notifications are sent to the address that you specified in the Return-Path header of the original email.
You’re required to have a method of tracking bounces and complaints. If you haven’t set up another mechanism for receiving bounce or complaint notifications (for example, by setting up an event destination), you receive an email notification when these events occur (even if this setting is disabled).
7277 7278 7279 7280 7281 7282 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7277 class PutEmailIdentityFeedbackAttributesRequest < Struct.new( :email_identity, :email_forwarding_enabled) SENSITIVE = [] include Aws::Structure end |
#email_identity ⇒ String
The email identity.
7277 7278 7279 7280 7281 7282 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7277 class PutEmailIdentityFeedbackAttributesRequest < Struct.new( :email_identity, :email_forwarding_enabled) SENSITIVE = [] include Aws::Structure end |