Class: Aws::SESV2::Types::PutEmailIdentityMailFromAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::PutEmailIdentityMailFromAttributesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to configure the custom MAIL FROM domain for a verified identity.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#behavior_on_mx_failure ⇒ String
The action to take if the required MX record isn't found when you send an email.
-
#email_identity ⇒ String
The verified email identity.
-
#mail_from_domain ⇒ String
The custom MAIL FROM domain that you want the verified identity to use.
Instance Attribute Details
#behavior_on_mx_failure ⇒ String
The action to take if the required MX record isn't found when you
send an email. When you set this value to UseDefaultValue, the
mail is sent using amazonses.com as the MAIL FROM domain. When you
set this value to RejectMessage, the Amazon SES API v2 returns a
MailFromDomainNotVerified error, and doesn't attempt to deliver
the email.
These behaviors are taken when the custom MAIL FROM domain
configuration is in the Pending, Failed, and TemporaryFailure
states.
7441 7442 7443 7444 7445 7446 7447 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7441 class PutEmailIdentityMailFromAttributesRequest < Struct.new( :email_identity, :mail_from_domain, :behavior_on_mx_failure) SENSITIVE = [] include Aws::Structure end |
#email_identity ⇒ String
The verified email identity.
7441 7442 7443 7444 7445 7446 7447 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7441 class PutEmailIdentityMailFromAttributesRequest < Struct.new( :email_identity, :mail_from_domain, :behavior_on_mx_failure) SENSITIVE = [] include Aws::Structure end |
#mail_from_domain ⇒ String
The custom MAIL FROM domain that you want the verified identity to use. The MAIL FROM domain must meet the following criteria:
-
It has to be a subdomain of the verified identity.
-
It can't be used to receive email.
-
It can't be used in a "From" address if the MAIL FROM domain is a destination for feedback forwarding emails.
7441 7442 7443 7444 7445 7446 7447 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7441 class PutEmailIdentityMailFromAttributesRequest < Struct.new( :email_identity, :mail_from_domain, :behavior_on_mx_failure) SENSITIVE = [] include Aws::Structure end |