Class: Aws::SESV2::Types::ReputationEntity

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

An object that contains information about a reputation entity, including its reference, type, policy, status records, and reputation impact.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#aws_ses_managed_statusTypes::StatusRecord

The Amazon Web Services Amazon SES-managed status record for this reputation entity, including the current status, cause description, and last updated timestamp.



7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
7556
# File 'lib/aws-sdk-sesv2/types.rb', line 7546

class ReputationEntity < Struct.new(
  :reputation_entity_reference,
  :reputation_entity_type,
  :reputation_management_policy,
  :customer_managed_status,
  :aws_ses_managed_status,
  :sending_status_aggregate,
  :reputation_impact)
  SENSITIVE = []
  include Aws::Structure
end

#customer_managed_statusTypes::StatusRecord

The customer-managed status record for this reputation entity, including the current status, cause description, and last updated timestamp.



7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
7556
# File 'lib/aws-sdk-sesv2/types.rb', line 7546

class ReputationEntity < Struct.new(
  :reputation_entity_reference,
  :reputation_entity_type,
  :reputation_management_policy,
  :customer_managed_status,
  :aws_ses_managed_status,
  :sending_status_aggregate,
  :reputation_impact)
  SENSITIVE = []
  include Aws::Structure
end

#reputation_entity_referenceString

The unique identifier for the reputation entity. For resource-type entities, this is the Amazon Resource Name (ARN) of the resource.



7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
7556
# File 'lib/aws-sdk-sesv2/types.rb', line 7546

class ReputationEntity < Struct.new(
  :reputation_entity_reference,
  :reputation_entity_type,
  :reputation_management_policy,
  :customer_managed_status,
  :aws_ses_managed_status,
  :sending_status_aggregate,
  :reputation_impact)
  SENSITIVE = []
  include Aws::Structure
end

#reputation_entity_typeString

The type of reputation entity. Currently, only RESOURCE type entities are supported.



7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
7556
# File 'lib/aws-sdk-sesv2/types.rb', line 7546

class ReputationEntity < Struct.new(
  :reputation_entity_reference,
  :reputation_entity_type,
  :reputation_management_policy,
  :customer_managed_status,
  :aws_ses_managed_status,
  :sending_status_aggregate,
  :reputation_impact)
  SENSITIVE = []
  include Aws::Structure
end

#reputation_impactString

The reputation impact level for this entity, representing the highest impact reputation finding currently active. Reputation findings can be retrieved using the ListRecommendations operation.



7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
7556
# File 'lib/aws-sdk-sesv2/types.rb', line 7546

class ReputationEntity < Struct.new(
  :reputation_entity_reference,
  :reputation_entity_type,
  :reputation_management_policy,
  :customer_managed_status,
  :aws_ses_managed_status,
  :sending_status_aggregate,
  :reputation_impact)
  SENSITIVE = []
  include Aws::Structure
end

#reputation_management_policyString

The Amazon Resource Name (ARN) of the reputation management policy applied to this entity. This is an Amazon Web Services Amazon SES-managed policy.



7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
7556
# File 'lib/aws-sdk-sesv2/types.rb', line 7546

class ReputationEntity < Struct.new(
  :reputation_entity_reference,
  :reputation_entity_type,
  :reputation_management_policy,
  :customer_managed_status,
  :aws_ses_managed_status,
  :sending_status_aggregate,
  :reputation_impact)
  SENSITIVE = []
  include Aws::Structure
end

#sending_status_aggregateString

The aggregate sending status that determines whether the entity is allowed to send emails. This status is derived from both the customer-managed and Amazon Web Services Amazon SES-managed statuses. If either the customer-managed status or the Amazon Web Services Amazon SES-managed status is DISABLED, the aggregate status will be DISABLED and the entity will not be allowed to send emails. When the customer-managed status is set to REINSTATED, the entity can continue sending even if there are active reputation findings, provided the Amazon Web Services Amazon SES-managed status also permits sending. The entity can only send emails when both statuses permit sending.



7546
7547
7548
7549
7550
7551
7552
7553
7554
7555
7556
# File 'lib/aws-sdk-sesv2/types.rb', line 7546

class ReputationEntity < Struct.new(
  :reputation_entity_reference,
  :reputation_entity_type,
  :reputation_management_policy,
  :customer_managed_status,
  :aws_ses_managed_status,
  :sending_status_aggregate,
  :reputation_impact)
  SENSITIVE = []
  include Aws::Structure
end