Class: Aws::SESV2::Types::ReputationOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ReputationOptions
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Enable or disable collection of reputation metrics for emails that you send using this configuration set in the current Amazon Web Services Region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#last_fresh_start ⇒ Time
The date and time (in Unix time) when the reputation metrics were last given a fresh start.
-
#reputation_metrics_enabled ⇒ Boolean
If
true, tracking of reputation metrics is enabled for the configuration set.
Instance Attribute Details
#last_fresh_start ⇒ Time
The date and time (in Unix time) when the reputation metrics were last given a fresh start. When your account is given a fresh start, your reputation metrics are calculated starting from the date of the fresh start.
7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7747 class ReputationOptions < Struct.new( :reputation_metrics_enabled, :last_fresh_start) SENSITIVE = [] include Aws::Structure end |
#reputation_metrics_enabled ⇒ Boolean
If true, tracking of reputation metrics is enabled for the
configuration set. If false, tracking of reputation metrics is
disabled for the configuration set.
7747 7748 7749 7750 7751 7752 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7747 class ReputationOptions < Struct.new( :reputation_metrics_enabled, :last_fresh_start) SENSITIVE = [] include Aws::Structure end |