Class: Aws::SESV2::Types::SendBulkEmailRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::SendBulkEmailRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Represents a request to send email messages to multiple destinations using Amazon SES. For more information, see the [Amazon SES Developer Guide].
[1]: docs.aws.amazon.com/ses/latest/DeveloperGuide/send-personalized-email-api.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bulk_email_entries ⇒ Array<Types::BulkEmailEntry>
The list of bulk email entry objects.
-
#configuration_set_name ⇒ String
The name of the configuration set to use when sending the email.
-
#default_content ⇒ Types::BulkEmailContent
An object that contains the body of the message.
-
#default_email_tags ⇒ Array<Types::MessageTag>
A list of tags, in the form of name/value pairs, to apply to an email that you send using the
SendEmailoperation. -
#endpoint_id ⇒ String
The ID of the multi-region endpoint (global-endpoint).
-
#feedback_forwarding_email_address ⇒ String
The address that you want bounce and complaint notifications to be sent to.
-
#feedback_forwarding_email_address_identity_arn ⇒ String
This parameter is used only for sending authorization.
-
#from_email_address ⇒ String
The email address to use as the “From” address for the email.
-
#from_email_address_identity_arn ⇒ String
This parameter is used only for sending authorization.
-
#reply_to_addresses ⇒ Array<String>
The “Reply-to” email addresses for the message.
-
#tenant_name ⇒ String
The name of the tenant through which this bulk email will be sent.
Instance Attribute Details
#bulk_email_entries ⇒ Array<Types::BulkEmailEntry>
The list of bulk email entry objects.
7802 7803 7804 7805 7806 7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7802 class SendBulkEmailRequest < Struct.new( :from_email_address, :from_email_address_identity_arn, :reply_to_addresses, :feedback_forwarding_email_address, :feedback_forwarding_email_address_identity_arn, :default_email_tags, :default_content, :bulk_email_entries, :configuration_set_name, :endpoint_id, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#configuration_set_name ⇒ String
The name of the configuration set to use when sending the email.
7802 7803 7804 7805 7806 7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7802 class SendBulkEmailRequest < Struct.new( :from_email_address, :from_email_address_identity_arn, :reply_to_addresses, :feedback_forwarding_email_address, :feedback_forwarding_email_address_identity_arn, :default_email_tags, :default_content, :bulk_email_entries, :configuration_set_name, :endpoint_id, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#default_content ⇒ Types::BulkEmailContent
An object that contains the body of the message. You can specify a template message.
7802 7803 7804 7805 7806 7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7802 class SendBulkEmailRequest < Struct.new( :from_email_address, :from_email_address_identity_arn, :reply_to_addresses, :feedback_forwarding_email_address, :feedback_forwarding_email_address_identity_arn, :default_email_tags, :default_content, :bulk_email_entries, :configuration_set_name, :endpoint_id, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#default_email_tags ⇒ Array<Types::MessageTag>
A list of tags, in the form of name/value pairs, to apply to an email that you send using the SendEmail operation. Tags correspond to characteristics of the email that you define, so that you can publish email sending events.
7802 7803 7804 7805 7806 7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7802 class SendBulkEmailRequest < Struct.new( :from_email_address, :from_email_address_identity_arn, :reply_to_addresses, :feedback_forwarding_email_address, :feedback_forwarding_email_address_identity_arn, :default_email_tags, :default_content, :bulk_email_entries, :configuration_set_name, :endpoint_id, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#endpoint_id ⇒ String
The ID of the multi-region endpoint (global-endpoint).
7802 7803 7804 7805 7806 7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7802 class SendBulkEmailRequest < Struct.new( :from_email_address, :from_email_address_identity_arn, :reply_to_addresses, :feedback_forwarding_email_address, :feedback_forwarding_email_address_identity_arn, :default_email_tags, :default_content, :bulk_email_entries, :configuration_set_name, :endpoint_id, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#feedback_forwarding_email_address ⇒ String
The address that you want bounce and complaint notifications to be sent to.
7802 7803 7804 7805 7806 7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7802 class SendBulkEmailRequest < Struct.new( :from_email_address, :from_email_address_identity_arn, :reply_to_addresses, :feedback_forwarding_email_address, :feedback_forwarding_email_address_identity_arn, :default_email_tags, :default_content, :bulk_email_entries, :configuration_set_name, :endpoint_id, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#feedback_forwarding_email_address_identity_arn ⇒ String
This parameter is used only for sending authorization. It is the ARN of the identity that is associated with the sending authorization policy that permits you to use the email address specified in the FeedbackForwardingEmailAddress parameter.
For example, if the owner of example.com (which has ARN arn:aws:ses:us-east-1:123456789012:identity/example.com) attaches a policy to it that authorizes you to use [email protected], then you would specify the FeedbackForwardingEmailAddressIdentityArn to be arn:aws:ses:us-east-1:123456789012:identity/example.com, and the FeedbackForwardingEmailAddress to be [email protected].
For more information about sending authorization, see the [Amazon SES Developer Guide].
[1]: docs.aws.amazon.com/ses/latest/DeveloperGuide/sending-authorization.html
7802 7803 7804 7805 7806 7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7802 class SendBulkEmailRequest < Struct.new( :from_email_address, :from_email_address_identity_arn, :reply_to_addresses, :feedback_forwarding_email_address, :feedback_forwarding_email_address_identity_arn, :default_email_tags, :default_content, :bulk_email_entries, :configuration_set_name, :endpoint_id, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#from_email_address ⇒ String
The email address to use as the “From” address for the email. The address that you specify has to be verified.
7802 7803 7804 7805 7806 7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7802 class SendBulkEmailRequest < Struct.new( :from_email_address, :from_email_address_identity_arn, :reply_to_addresses, :feedback_forwarding_email_address, :feedback_forwarding_email_address_identity_arn, :default_email_tags, :default_content, :bulk_email_entries, :configuration_set_name, :endpoint_id, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#from_email_address_identity_arn ⇒ String
This parameter is used only for sending authorization. It is the ARN of the identity that is associated with the sending authorization policy that permits you to use the email address specified in the FromEmailAddress parameter.
For example, if the owner of example.com (which has ARN arn:aws:ses:us-east-1:123456789012:identity/example.com) attaches a policy to it that authorizes you to use [email protected], then you would specify the FromEmailAddressIdentityArn to be arn:aws:ses:us-east-1:123456789012:identity/example.com, and the FromEmailAddress to be [email protected].
For more information about sending authorization, see the [Amazon SES Developer Guide].
[1]: docs.aws.amazon.com/ses/latest/DeveloperGuide/sending-authorization.html
7802 7803 7804 7805 7806 7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7802 class SendBulkEmailRequest < Struct.new( :from_email_address, :from_email_address_identity_arn, :reply_to_addresses, :feedback_forwarding_email_address, :feedback_forwarding_email_address_identity_arn, :default_email_tags, :default_content, :bulk_email_entries, :configuration_set_name, :endpoint_id, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#reply_to_addresses ⇒ Array<String>
The “Reply-to” email addresses for the message. When the recipient replies to the message, each Reply-to address receives the reply.
7802 7803 7804 7805 7806 7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7802 class SendBulkEmailRequest < Struct.new( :from_email_address, :from_email_address_identity_arn, :reply_to_addresses, :feedback_forwarding_email_address, :feedback_forwarding_email_address_identity_arn, :default_email_tags, :default_content, :bulk_email_entries, :configuration_set_name, :endpoint_id, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#tenant_name ⇒ String
The name of the tenant through which this bulk email will be sent.
<note markdown=“1”> The email sending operation will only succeed if all referenced resources (identities, configuration sets, and templates) are associated with this tenant.
</note>
7802 7803 7804 7805 7806 7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7802 class SendBulkEmailRequest < Struct.new( :from_email_address, :from_email_address_identity_arn, :reply_to_addresses, :feedback_forwarding_email_address, :feedback_forwarding_email_address_identity_arn, :default_email_tags, :default_content, :bulk_email_entries, :configuration_set_name, :endpoint_id, :tenant_name) SENSITIVE = [] include Aws::Structure end |