Class: Aws::SESV2::Types::SendEmailRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

Represents a request to send a single formatted email using Amazon SES. For more information, see the Amazon SES Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#configuration_overridesTypes::ConfigurationOverrides

An object that overrides, for this message only, settings that would otherwise apply to it. Each setting that you don't override keeps the value that already applies.



8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-sesv2/types.rb', line 8209

class SendEmailRequest < Struct.new(
  :from_email_address,
  :from_email_address_identity_arn,
  :destination,
  :reply_to_addresses,
  :feedback_forwarding_email_address,
  :feedback_forwarding_email_address_identity_arn,
  :content,
  :email_tags,
  :configuration_set_name,
  :endpoint_id,
  :tenant_name,
  :list_management_options,
  :configuration_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#configuration_set_nameString

The name of the configuration set to use when sending the email.

Returns:

  • (String)


8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-sesv2/types.rb', line 8209

class SendEmailRequest < Struct.new(
  :from_email_address,
  :from_email_address_identity_arn,
  :destination,
  :reply_to_addresses,
  :feedback_forwarding_email_address,
  :feedback_forwarding_email_address_identity_arn,
  :content,
  :email_tags,
  :configuration_set_name,
  :endpoint_id,
  :tenant_name,
  :list_management_options,
  :configuration_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#contentTypes::EmailContent

An object that contains the body of the message. You can send either a Simple message, Raw message, or a Templated message.

Returns:



8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-sesv2/types.rb', line 8209

class SendEmailRequest < Struct.new(
  :from_email_address,
  :from_email_address_identity_arn,
  :destination,
  :reply_to_addresses,
  :feedback_forwarding_email_address,
  :feedback_forwarding_email_address_identity_arn,
  :content,
  :email_tags,
  :configuration_set_name,
  :endpoint_id,
  :tenant_name,
  :list_management_options,
  :configuration_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#destinationTypes::Destination

An object that contains the recipients of the email message.

Returns:



8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-sesv2/types.rb', line 8209

class SendEmailRequest < Struct.new(
  :from_email_address,
  :from_email_address_identity_arn,
  :destination,
  :reply_to_addresses,
  :feedback_forwarding_email_address,
  :feedback_forwarding_email_address_identity_arn,
  :content,
  :email_tags,
  :configuration_set_name,
  :endpoint_id,
  :tenant_name,
  :list_management_options,
  :configuration_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#email_tagsArray<Types::MessageTag>

A list of tags, in the form of name/value pairs, to apply to an email that you send using the SendEmail operation. Tags correspond to characteristics of the email that you define, so that you can publish email sending events.

Returns:



8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-sesv2/types.rb', line 8209

class SendEmailRequest < Struct.new(
  :from_email_address,
  :from_email_address_identity_arn,
  :destination,
  :reply_to_addresses,
  :feedback_forwarding_email_address,
  :feedback_forwarding_email_address_identity_arn,
  :content,
  :email_tags,
  :configuration_set_name,
  :endpoint_id,
  :tenant_name,
  :list_management_options,
  :configuration_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_idString

The ID of the multi-region endpoint (global-endpoint).

Returns:

  • (String)


8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-sesv2/types.rb', line 8209

class SendEmailRequest < Struct.new(
  :from_email_address,
  :from_email_address_identity_arn,
  :destination,
  :reply_to_addresses,
  :feedback_forwarding_email_address,
  :feedback_forwarding_email_address_identity_arn,
  :content,
  :email_tags,
  :configuration_set_name,
  :endpoint_id,
  :tenant_name,
  :list_management_options,
  :configuration_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#feedback_forwarding_email_addressString

The address that you want bounce and complaint notifications to be sent to.

Returns:

  • (String)


8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-sesv2/types.rb', line 8209

class SendEmailRequest < Struct.new(
  :from_email_address,
  :from_email_address_identity_arn,
  :destination,
  :reply_to_addresses,
  :feedback_forwarding_email_address,
  :feedback_forwarding_email_address_identity_arn,
  :content,
  :email_tags,
  :configuration_set_name,
  :endpoint_id,
  :tenant_name,
  :list_management_options,
  :configuration_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#feedback_forwarding_email_address_identity_arnString

This parameter is used only for sending authorization. It is the ARN of the identity that is associated with the sending authorization policy that permits you to use the email address specified in the FeedbackForwardingEmailAddress parameter.

For example, if the owner of example.com (which has ARN arn:aws:ses:us-east-1:123456789012:identity/example.com) attaches a policy to it that authorizes you to use feedback@example.com, then you would specify the FeedbackForwardingEmailAddressIdentityArn to be arn:aws:ses:us-east-1:123456789012:identity/example.com, and the FeedbackForwardingEmailAddress to be feedback@example.com.

For more information about sending authorization, see the Amazon SES Developer Guide.

Returns:

  • (String)


8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-sesv2/types.rb', line 8209

class SendEmailRequest < Struct.new(
  :from_email_address,
  :from_email_address_identity_arn,
  :destination,
  :reply_to_addresses,
  :feedback_forwarding_email_address,
  :feedback_forwarding_email_address_identity_arn,
  :content,
  :email_tags,
  :configuration_set_name,
  :endpoint_id,
  :tenant_name,
  :list_management_options,
  :configuration_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#from_email_addressString

The email address to use as the "From" address for the email. The address that you specify has to be verified.

Returns:

  • (String)


8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-sesv2/types.rb', line 8209

class SendEmailRequest < Struct.new(
  :from_email_address,
  :from_email_address_identity_arn,
  :destination,
  :reply_to_addresses,
  :feedback_forwarding_email_address,
  :feedback_forwarding_email_address_identity_arn,
  :content,
  :email_tags,
  :configuration_set_name,
  :endpoint_id,
  :tenant_name,
  :list_management_options,
  :configuration_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#from_email_address_identity_arnString

This parameter is used only for sending authorization. It is the ARN of the identity that is associated with the sending authorization policy that permits you to use the email address specified in the FromEmailAddress parameter.

For example, if the owner of example.com (which has ARN arn:aws:ses:us-east-1:123456789012:identity/example.com) attaches a policy to it that authorizes you to use sender@example.com, then you would specify the FromEmailAddressIdentityArn to be arn:aws:ses:us-east-1:123456789012:identity/example.com, and the FromEmailAddress to be sender@example.com.

For more information about sending authorization, see the Amazon SES Developer Guide.

For Raw emails, the FromEmailAddressIdentityArn value overrides the X-SES-SOURCE-ARN and X-SES-FROM-ARN headers specified in raw email message content.

Returns:

  • (String)


8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-sesv2/types.rb', line 8209

class SendEmailRequest < Struct.new(
  :from_email_address,
  :from_email_address_identity_arn,
  :destination,
  :reply_to_addresses,
  :feedback_forwarding_email_address,
  :feedback_forwarding_email_address_identity_arn,
  :content,
  :email_tags,
  :configuration_set_name,
  :endpoint_id,
  :tenant_name,
  :list_management_options,
  :configuration_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#list_management_optionsTypes::ListManagementOptions

An object used to specify a list or topic to which an email belongs, which will be used when a contact chooses to unsubscribe.



8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-sesv2/types.rb', line 8209

class SendEmailRequest < Struct.new(
  :from_email_address,
  :from_email_address_identity_arn,
  :destination,
  :reply_to_addresses,
  :feedback_forwarding_email_address,
  :feedback_forwarding_email_address_identity_arn,
  :content,
  :email_tags,
  :configuration_set_name,
  :endpoint_id,
  :tenant_name,
  :list_management_options,
  :configuration_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#reply_to_addressesArray<String>

The "Reply-to" email addresses for the message. When the recipient replies to the message, each Reply-to address receives the reply.

Returns:

  • (Array<String>)


8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-sesv2/types.rb', line 8209

class SendEmailRequest < Struct.new(
  :from_email_address,
  :from_email_address_identity_arn,
  :destination,
  :reply_to_addresses,
  :feedback_forwarding_email_address,
  :feedback_forwarding_email_address_identity_arn,
  :content,
  :email_tags,
  :configuration_set_name,
  :endpoint_id,
  :tenant_name,
  :list_management_options,
  :configuration_overrides)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_nameString

The name of the tenant through which this email will be sent.

The email sending operation will only succeed if all referenced resources (identities, configuration sets, and templates) are associated with this tenant.

Returns:

  • (String)


8209
8210
8211
8212
8213
8214
8215
8216
8217
8218
8219
8220
8221
8222
8223
8224
8225
# File 'lib/aws-sdk-sesv2/types.rb', line 8209

class SendEmailRequest < Struct.new(
  :from_email_address,
  :from_email_address_identity_arn,
  :destination,
  :reply_to_addresses,
  :feedback_forwarding_email_address,
  :feedback_forwarding_email_address_identity_arn,
  :content,
  :email_tags,
  :configuration_set_name,
  :endpoint_id,
  :tenant_name,
  :list_management_options,
  :configuration_overrides)
  SENSITIVE = []
  include Aws::Structure
end