Class: Aws::SESV2::Types::SuppressedDestination

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

An object that contains information about an email address that is on the suppression list for your account or for a specific tenant.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#attributesTypes::SuppressedDestinationAttributes

An optional value that can contain additional information about the reasons that the address was added to the suppression list for your account or for a specific tenant.



8273
8274
8275
8276
8277
8278
8279
8280
8281
# File 'lib/aws-sdk-sesv2/types.rb', line 8273

class SuppressedDestination < Struct.new(
  :email_address,
  :reason,
  :last_update_time,
  :attributes,
  :tenant_name)
  SENSITIVE = []
  include Aws::Structure
end

#email_addressString

The email address that is on the suppression list for your account or for a specific tenant.

Returns:

  • (String)


8273
8274
8275
8276
8277
8278
8279
8280
8281
# File 'lib/aws-sdk-sesv2/types.rb', line 8273

class SuppressedDestination < Struct.new(
  :email_address,
  :reason,
  :last_update_time,
  :attributes,
  :tenant_name)
  SENSITIVE = []
  include Aws::Structure
end

#last_update_timeTime

The date and time when the suppressed destination was last updated, shown in Unix time format.

Returns:

  • (Time)


8273
8274
8275
8276
8277
8278
8279
8280
8281
# File 'lib/aws-sdk-sesv2/types.rb', line 8273

class SuppressedDestination < Struct.new(
  :email_address,
  :reason,
  :last_update_time,
  :attributes,
  :tenant_name)
  SENSITIVE = []
  include Aws::Structure
end

#reasonString

The reason that the address was added to the suppression list for your account or for a specific tenant.

Returns:

  • (String)


8273
8274
8275
8276
8277
8278
8279
8280
8281
# File 'lib/aws-sdk-sesv2/types.rb', line 8273

class SuppressedDestination < Struct.new(
  :email_address,
  :reason,
  :last_update_time,
  :attributes,
  :tenant_name)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_nameString

The name of the tenant that the suppressed destination belongs to. This field is present only when the suppressed destination is on a tenant’s suppression list.

Returns:

  • (String)


8273
8274
8275
8276
8277
8278
8279
8280
8281
# File 'lib/aws-sdk-sesv2/types.rb', line 8273

class SuppressedDestination < Struct.new(
  :email_address,
  :reason,
  :last_update_time,
  :attributes,
  :tenant_name)
  SENSITIVE = []
  include Aws::Structure
end