Class: Aws::SESV2::Types::SuppressionOptions
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::SuppressionOptions
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
An object that contains information about the suppression list preferences for your account or for a specific tenant.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#suppressed_reasons ⇒ Array<String>
A list that contains the reasons that email addresses are automatically added to the suppression list for your account or for a specific tenant.
-
#suppression_scope ⇒ String
The suppression scope for the configuration set.
-
#validation_options ⇒ Types::SuppressionValidationOptions
Contains validation options for email address suppression.
Instance Attribute Details
#suppressed_reasons ⇒ Array<String>
A list that contains the reasons that email addresses are automatically added to the suppression list for your account or for a specific tenant. This list can contain any or all of the following:
-
‘COMPLAINT` – Amazon SES adds an email address to the suppression list for your account or for a specific tenant when a message sent to that address results in a complaint.
-
‘BOUNCE` – Amazon SES adds an email address to the suppression list for your account or for a specific tenant when a message sent to that address results in a hard bounce.
8462 8463 8464 8465 8466 8467 8468 |
# File 'lib/aws-sdk-sesv2/types.rb', line 8462 class SuppressionOptions < Struct.new( :suppressed_reasons, :suppression_scope, :validation_options) SENSITIVE = [] include Aws::Structure end |
#suppression_scope ⇒ String
The suppression scope for the configuration set. This overrides the tenant or account suppression scope for emails sent using this configuration set. Can be one of the following:
-
‘TENANT` – Use the tenant’s suppression list.
-
‘ACCOUNT` – Use the account-level suppression list.
8462 8463 8464 8465 8466 8467 8468 |
# File 'lib/aws-sdk-sesv2/types.rb', line 8462 class SuppressionOptions < Struct.new( :suppressed_reasons, :suppression_scope, :validation_options) SENSITIVE = [] include Aws::Structure end |
#validation_options ⇒ Types::SuppressionValidationOptions
Contains validation options for email address suppression.
8462 8463 8464 8465 8466 8467 8468 |
# File 'lib/aws-sdk-sesv2/types.rb', line 8462 class SuppressionOptions < Struct.new( :suppressed_reasons, :suppression_scope, :validation_options) SENSITIVE = [] include Aws::Structure end |