Class: Aws::SESV2::Types::TenantSuppressionAttributes

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

An object that contains the suppression list preferences for a tenant.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#suppressed_reasonsArray<String>

A list that contains the reasons that email addresses are automatically added to the suppression list for the tenant. This list can contain any or all of the following:

  • ‘COMPLAINT` – Amazon SES adds an email address to the suppression list when a message sent to that address results in a complaint.

  • ‘BOUNCE` – Amazon SES adds an email address to the suppression list when a message sent to that address results in a hard bounce.

Returns:

  • (Array<String>)


8762
8763
8764
8765
8766
8767
# File 'lib/aws-sdk-sesv2/types.rb', line 8762

class TenantSuppressionAttributes < Struct.new(
  :suppressed_reasons,
  :suppression_scope)
  SENSITIVE = []
  include Aws::Structure
end

#suppression_scopeString

The suppression scope for the tenant. Can be one of the following:

  • ‘TENANT` – The tenant uses its own suppression list.

  • ‘ACCOUNT` – The tenant uses the account-level suppression list.

<note markdown=“1”> If you don’t specify a suppression scope, the tenant defaults to ‘ACCOUNT` scope and uses the account-level suppression list.

</note>

Returns:

  • (String)


8762
8763
8764
8765
8766
8767
# File 'lib/aws-sdk-sesv2/types.rb', line 8762

class TenantSuppressionAttributes < Struct.new(
  :suppressed_reasons,
  :suppression_scope)
  SENSITIVE = []
  include Aws::Structure
end