Class: Aws::SESV2::Types::TrackingConfigurationOverrides
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::TrackingConfigurationOverrides
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
An object that overrides, for a single email sending request, the engagement tracking settings that would otherwise apply. Use these overrides to turn open tracking or click tracking on or off for an individual message, for example to suppress tracking in a transactional message that you send from an account or a configuration set that has tracking enabled.
Without an override, engagement tracking is determined by your
account-level EngagementMetrics setting, which you configure using
the PutAccountVdmAttributes operation, by the EngagementMetrics
setting of the configuration set that the message uses, which you
configure using the PutConfigurationSetVdmOptions operation, and by
whether that configuration set has an event destination whose
MatchingEventTypes include the OPEN or CLICK event types.
For more information about tracking open and click events, see the Amazon SES Developer Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#click_tracking_enabled ⇒ String
Specifies whether Amazon SES tracks when the recipient clicks a link in this message.
-
#open_tracking_enabled ⇒ String
Specifies whether Amazon SES tracks when the recipient opens this message.
Instance Attribute Details
#click_tracking_enabled ⇒ String
Specifies whether Amazon SES tracks when the recipient clicks a link in this message. Can be one of the following:
-
ENABLED– Amazon SES tracks clicks for this message, even when your account-level and configuration set settings don't enable click tracking. -
DISABLED– Amazon SES doesn't track clicks for this message, even when your account-level or configuration set settings enable click tracking. Amazon SES doesn't rewrite the links in the message.
If you don't specify this value, Amazon SES uses the click tracking setting that would otherwise apply to the message.
9076 9077 9078 9079 9080 9081 |
# File 'lib/aws-sdk-sesv2/types.rb', line 9076 class TrackingConfigurationOverrides < Struct.new( :open_tracking_enabled, :click_tracking_enabled) SENSITIVE = [] include Aws::Structure end |
#open_tracking_enabled ⇒ String
Specifies whether Amazon SES tracks when the recipient opens this message. Can be one of the following:
-
ENABLED– Amazon SES tracks opens for this message, even when your account-level and configuration set settings don't enable open tracking. -
DISABLED– Amazon SES doesn't track opens for this message, even when your account-level or configuration set settings enable open tracking. Amazon SES doesn't add the tracking image to the message.
If you don't specify this value, Amazon SES uses the open tracking setting that would otherwise apply to the message.
9076 9077 9078 9079 9080 9081 |
# File 'lib/aws-sdk-sesv2/types.rb', line 9076 class TrackingConfigurationOverrides < Struct.new( :open_tracking_enabled, :click_tracking_enabled) SENSITIVE = [] include Aws::Structure end |