Class: Aws::SESV2::Types::CreateTenantRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::CreateTenantRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Represents a request to create a tenant.
Tenants are logical containers that group related SES resources together. Each tenant can have its own set of resources like email identities, configuration sets, and templates, along with reputation metrics and sending status. This helps isolate and manage email sending for different customers or business units within your Amazon SES API v2 account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#suppression_attributes ⇒ Types::TenantSuppressionAttributes
An object that contains information about the suppression list preferences for the tenant.
-
#tags ⇒ Array<Types::Tag>
An array of objects that define the tags (keys and values) to associate with the tenant.
-
#tenant_name ⇒ String
The name of the tenant to create.
Instance Attribute Details
#suppression_attributes ⇒ Types::TenantSuppressionAttributes
An object that contains information about the suppression list preferences for the tenant. Use this to configure tenant-level suppression at creation time.
1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-sesv2/types.rb', line 1416 class CreateTenantRequest < Struct.new( :tenant_name, :tags, :suppression_attributes) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of objects that define the tags (keys and values) to associate with the tenant
1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-sesv2/types.rb', line 1416 class CreateTenantRequest < Struct.new( :tenant_name, :tags, :suppression_attributes) SENSITIVE = [] include Aws::Structure end |
#tenant_name ⇒ String
The name of the tenant to create. The name can contain up to 64 alphanumeric characters, including letters, numbers, hyphens (-) and underscores (_) only.
1416 1417 1418 1419 1420 1421 1422 |
# File 'lib/aws-sdk-sesv2/types.rb', line 1416 class CreateTenantRequest < Struct.new( :tenant_name, :tags, :suppression_attributes) SENSITIVE = [] include Aws::Structure end |