Class: Aws::SESV2::Types::CreateTenantRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

Represents a request to create a tenant.

Tenants are logical containers that group related SES resources together. Each tenant can have its own set of resources like email identities, configuration sets, and templates, along with reputation metrics and sending status. This helps isolate and manage email sending for different customers or business units within your Amazon SES API v2 account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#suppression_attributesTypes::TenantSuppressionAttributes

An object that contains information about the suppression list preferences for the tenant. Use this to configure tenant-level suppression at creation time.



1393
1394
1395
1396
1397
1398
1399
# File 'lib/aws-sdk-sesv2/types.rb', line 1393

class CreateTenantRequest < Struct.new(
  :tenant_name,
  :tags,
  :suppression_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

An array of objects that define the tags (keys and values) to associate with the tenant

Returns:



1393
1394
1395
1396
1397
1398
1399
# File 'lib/aws-sdk-sesv2/types.rb', line 1393

class CreateTenantRequest < Struct.new(
  :tenant_name,
  :tags,
  :suppression_attributes)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_nameString

The name of the tenant to create. The name can contain up to 64 alphanumeric characters, including letters, numbers, hyphens (-) and underscores (_) only.

Returns:

  • (String)


1393
1394
1395
1396
1397
1398
1399
# File 'lib/aws-sdk-sesv2/types.rb', line 1393

class CreateTenantRequest < Struct.new(
  :tenant_name,
  :tags,
  :suppression_attributes)
  SENSITIVE = []
  include Aws::Structure
end