Class: Aws::SESV2::Types::DeleteSuppressedDestinationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::DeleteSuppressedDestinationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to remove an email address from the suppression list for your account or for a specific tenant.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#email_address ⇒ String
The suppressed email destination to remove from the suppression list for your account or for the specified tenant.
-
#tenant_name ⇒ String
The name of the tenant whose suppression list you want to remove the address from.
Instance Attribute Details
#email_address ⇒ String
The suppressed email destination to remove from the suppression list for your account or for the specified tenant.
1942 1943 1944 1945 1946 1947 |
# File 'lib/aws-sdk-sesv2/types.rb', line 1942 class DeleteSuppressedDestinationRequest < Struct.new( :email_address, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#tenant_name ⇒ String
The name of the tenant whose suppression list you want to remove the address from. If you omit this parameter, the address is removed from the account-level suppression list.
1942 1943 1944 1945 1946 1947 |
# File 'lib/aws-sdk-sesv2/types.rb', line 1942 class DeleteSuppressedDestinationRequest < Struct.new( :email_address, :tenant_name) SENSITIVE = [] include Aws::Structure end |