Class: Aws::SESV2::Types::DeliverabilityTestReport
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::DeliverabilityTestReport
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
An object that contains metadata related to a predictive inbox placement test.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_date ⇒ Time
The date and time when the predictive inbox placement test was created.
-
#deliverability_test_status ⇒ String
The status of the predictive inbox placement test.
-
#from_email_address ⇒ String
The sender address that you specified for the predictive inbox placement test.
-
#report_id ⇒ String
A unique string that identifies the predictive inbox placement test.
-
#report_name ⇒ String
A name that helps you identify a predictive inbox placement test report.
-
#subject ⇒ String
The subject line for an email that you submitted in a predictive inbox placement test.
Instance Attribute Details
#create_date ⇒ Time
The date and time when the predictive inbox placement test was created.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2043 class DeliverabilityTestReport < Struct.new( :report_id, :report_name, :subject, :from_email_address, :create_date, :deliverability_test_status) SENSITIVE = [] include Aws::Structure end |
#deliverability_test_status ⇒ String
The status of the predictive inbox placement test. If the status is
IN_PROGRESS, then the predictive inbox placement test is currently
running. Predictive inbox placement tests are usually complete
within 24 hours of creating the test. If the status is COMPLETE,
then the test is finished, and you can use the
GetDeliverabilityTestReport to view the results of the test.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2043 class DeliverabilityTestReport < Struct.new( :report_id, :report_name, :subject, :from_email_address, :create_date, :deliverability_test_status) SENSITIVE = [] include Aws::Structure end |
#from_email_address ⇒ String
The sender address that you specified for the predictive inbox placement test.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2043 class DeliverabilityTestReport < Struct.new( :report_id, :report_name, :subject, :from_email_address, :create_date, :deliverability_test_status) SENSITIVE = [] include Aws::Structure end |
#report_id ⇒ String
A unique string that identifies the predictive inbox placement test.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2043 class DeliverabilityTestReport < Struct.new( :report_id, :report_name, :subject, :from_email_address, :create_date, :deliverability_test_status) SENSITIVE = [] include Aws::Structure end |
#report_name ⇒ String
A name that helps you identify a predictive inbox placement test report.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2043 class DeliverabilityTestReport < Struct.new( :report_id, :report_name, :subject, :from_email_address, :create_date, :deliverability_test_status) SENSITIVE = [] include Aws::Structure end |
#subject ⇒ String
The subject line for an email that you submitted in a predictive inbox placement test.
2043 2044 2045 2046 2047 2048 2049 2050 2051 2052 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2043 class DeliverabilityTestReport < Struct.new( :report_id, :report_name, :subject, :from_email_address, :create_date, :deliverability_test_status) SENSITIVE = [] include Aws::Structure end |