Class: Aws::SESV2::Types::DomainIspPlacement
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::DomainIspPlacement
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
An object that contains inbox placement data for email sent from one of your email domains to a specific email provider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inbox_percentage ⇒ Float
The percentage of messages that were sent from the selected domain to the specified email provider that arrived in recipients' inboxes.
-
#inbox_raw_count ⇒ Integer
The total number of messages that were sent from the selected domain to the specified email provider that arrived in recipients' inboxes.
-
#isp_name ⇒ String
The name of the email provider that the inbox placement data applies to.
-
#spam_percentage ⇒ Float
The percentage of messages that were sent from the selected domain to the specified email provider that arrived in recipients' spam or junk mail folders.
-
#spam_raw_count ⇒ Integer
The total number of messages that were sent from the selected domain to the specified email provider that arrived in recipients' spam or junk mail folders.
Instance Attribute Details
#inbox_percentage ⇒ Float
The percentage of messages that were sent from the selected domain to the specified email provider that arrived in recipients' inboxes.
2773 2774 2775 2776 2777 2778 2779 2780 2781 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2773 class DomainIspPlacement < Struct.new( :isp_name, :inbox_raw_count, :spam_raw_count, :inbox_percentage, :spam_percentage) SENSITIVE = [] include Aws::Structure end |
#inbox_raw_count ⇒ Integer
The total number of messages that were sent from the selected domain to the specified email provider that arrived in recipients' inboxes.
2773 2774 2775 2776 2777 2778 2779 2780 2781 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2773 class DomainIspPlacement < Struct.new( :isp_name, :inbox_raw_count, :spam_raw_count, :inbox_percentage, :spam_percentage) SENSITIVE = [] include Aws::Structure end |
#isp_name ⇒ String
The name of the email provider that the inbox placement data applies to.
2773 2774 2775 2776 2777 2778 2779 2780 2781 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2773 class DomainIspPlacement < Struct.new( :isp_name, :inbox_raw_count, :spam_raw_count, :inbox_percentage, :spam_percentage) SENSITIVE = [] include Aws::Structure end |
#spam_percentage ⇒ Float
The percentage of messages that were sent from the selected domain to the specified email provider that arrived in recipients' spam or junk mail folders.
2773 2774 2775 2776 2777 2778 2779 2780 2781 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2773 class DomainIspPlacement < Struct.new( :isp_name, :inbox_raw_count, :spam_raw_count, :inbox_percentage, :spam_percentage) SENSITIVE = [] include Aws::Structure end |
#spam_raw_count ⇒ Integer
The total number of messages that were sent from the selected domain to the specified email provider that arrived in recipients' spam or junk mail folders.
2773 2774 2775 2776 2777 2778 2779 2780 2781 |
# File 'lib/aws-sdk-sesv2/types.rb', line 2773 class DomainIspPlacement < Struct.new( :isp_name, :inbox_raw_count, :spam_raw_count, :inbox_percentage, :spam_percentage) SENSITIVE = [] include Aws::Structure end |