Class: Aws::SESV2::Types::GetDeliverabilityTestReportResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::GetDeliverabilityTestReportResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
The results of the predictive inbox placement test.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deliverability_test_report ⇒ Types::DeliverabilityTestReport
An object that contains the results of the predictive inbox placement test.
-
#isp_placements ⇒ Array<Types::IspPlacement>
An object that describes how the test email was handled by several email providers, including Gmail, Hotmail, Yahoo, AOL, and others.
-
#message ⇒ String
An object that contains the message that you sent when you performed this predictive inbox placement test.
-
#overall_placement ⇒ Types::PlacementStatistics
An object that specifies how many test messages that were sent during the predictive inbox placement test were delivered to recipients' inboxes, how many were sent to recipients' spam folders, and how many weren't delivered.
-
#tags ⇒ Array<Types::Tag>
An array of objects that define the tags (keys and values) that are associated with the predictive inbox placement test.
Instance Attribute Details
#deliverability_test_report ⇒ Types::DeliverabilityTestReport
An object that contains the results of the predictive inbox placement test.
4001 4002 4003 4004 4005 4006 4007 4008 4009 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4001 class GetDeliverabilityTestReportResponse < Struct.new( :deliverability_test_report, :overall_placement, :isp_placements, :message, :tags) SENSITIVE = [] include Aws::Structure end |
#isp_placements ⇒ Array<Types::IspPlacement>
An object that describes how the test email was handled by several email providers, including Gmail, Hotmail, Yahoo, AOL, and others.
4001 4002 4003 4004 4005 4006 4007 4008 4009 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4001 class GetDeliverabilityTestReportResponse < Struct.new( :deliverability_test_report, :overall_placement, :isp_placements, :message, :tags) SENSITIVE = [] include Aws::Structure end |
#message ⇒ String
An object that contains the message that you sent when you performed this predictive inbox placement test.
4001 4002 4003 4004 4005 4006 4007 4008 4009 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4001 class GetDeliverabilityTestReportResponse < Struct.new( :deliverability_test_report, :overall_placement, :isp_placements, :message, :tags) SENSITIVE = [] include Aws::Structure end |
#overall_placement ⇒ Types::PlacementStatistics
An object that specifies how many test messages that were sent during the predictive inbox placement test were delivered to recipients' inboxes, how many were sent to recipients' spam folders, and how many weren't delivered.
4001 4002 4003 4004 4005 4006 4007 4008 4009 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4001 class GetDeliverabilityTestReportResponse < Struct.new( :deliverability_test_report, :overall_placement, :isp_placements, :message, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An array of objects that define the tags (keys and values) that are associated with the predictive inbox placement test.
4001 4002 4003 4004 4005 4006 4007 4008 4009 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4001 class GetDeliverabilityTestReportResponse < Struct.new( :deliverability_test_report, :overall_placement, :isp_placements, :message, :tags) SENSITIVE = [] include Aws::Structure end |