Class: Aws::SESV2::Types::GetDomainStatisticsReportRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::GetDomainStatisticsReportRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to obtain deliverability metrics for a domain.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#domain ⇒ String
The domain that you want to obtain deliverability metrics for.
-
#end_date ⇒ Time
The last day (in Unix time) that you want to obtain domain deliverability metrics for.
-
#start_date ⇒ Time
The first day (in Unix time) that you want to obtain domain deliverability metrics for.
Instance Attribute Details
#domain ⇒ String
The domain that you want to obtain deliverability metrics for.
4036 4037 4038 4039 4040 4041 4042 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4036 class GetDomainStatisticsReportRequest < Struct.new( :domain, :start_date, :end_date) SENSITIVE = [] include Aws::Structure end |
#end_date ⇒ Time
The last day (in Unix time) that you want to obtain domain deliverability metrics for. The EndDate that you specify has to be less than or equal to 30 days after the StartDate.
4036 4037 4038 4039 4040 4041 4042 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4036 class GetDomainStatisticsReportRequest < Struct.new( :domain, :start_date, :end_date) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
The first day (in Unix time) that you want to obtain domain deliverability metrics for.
4036 4037 4038 4039 4040 4041 4042 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4036 class GetDomainStatisticsReportRequest < Struct.new( :domain, :start_date, :end_date) SENSITIVE = [] include Aws::Structure end |