Class: Aws::SESV2::Types::GetSuppressedDestinationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::GetSuppressedDestinationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to retrieve information about an email address that’s on the suppression list for your account or for a specific tenant.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#email_address ⇒ String
The email address that’s on the suppression list for your account or for the specified tenant.
-
#tenant_name ⇒ String
The name of the tenant whose suppression list you want to query.
Instance Attribute Details
#email_address ⇒ String
The email address that’s on the suppression list for your account or for the specified tenant.
4612 4613 4614 4615 4616 4617 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4612 class GetSuppressedDestinationRequest < Struct.new( :email_address, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#tenant_name ⇒ String
The name of the tenant whose suppression list you want to query. If you omit this parameter, the operation targets the account-level suppression list.
4612 4613 4614 4615 4616 4617 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4612 class GetSuppressedDestinationRequest < Struct.new( :email_address, :tenant_name) SENSITIVE = [] include Aws::Structure end |