Class: Aws::SESV2::Types::ListConfigurationSetsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListConfigurationSetsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A list of configuration sets in your Amazon SES account in the current Amazon Web Services Region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_sets ⇒ Array<String>
An array that contains all of the configuration sets in your Amazon SES account in the current Amazon Web Services Region.
-
#next_token ⇒ String
A token that indicates that there are additional configuration sets to list.
Instance Attribute Details
#configuration_sets ⇒ Array<String>
An array that contains all of the configuration sets in your Amazon SES account in the current Amazon Web Services Region.
4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4997 class ListConfigurationSetsResponse < Struct.new( :configuration_sets, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token that indicates that there are additional configuration sets to list. To view additional configuration sets, issue another request to ListConfigurationSets, and pass this token in the NextToken parameter.
4997 4998 4999 5000 5001 5002 |
# File 'lib/aws-sdk-sesv2/types.rb', line 4997 class ListConfigurationSetsResponse < Struct.new( :configuration_sets, :next_token) SENSITIVE = [] include Aws::Structure end |