Class: Aws::SESV2::Types::ListContactsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListContactsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#contact_list_name ⇒ String
The name of the contact list.
-
#filter ⇒ Types::ListContactsFilter
A filter that can be applied to a list of contacts.
-
#next_token ⇒ String
A string token indicating that there might be additional contacts available to be listed.
-
#page_size ⇒ Integer
The number of contacts that may be returned at once, which is dependent on if there are more or less contacts than the value of the PageSize.
Instance Attribute Details
#contact_list_name ⇒ String
The name of the contact list.
5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5093 class ListContactsRequest < Struct.new( :contact_list_name, :filter, :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#filter ⇒ Types::ListContactsFilter
A filter that can be applied to a list of contacts.
5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5093 class ListContactsRequest < Struct.new( :contact_list_name, :filter, :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A string token indicating that there might be additional contacts available to be listed. Use the token provided in the Response to use in the subsequent call to ListContacts with the same parameters to retrieve the next page of contacts.
5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5093 class ListContactsRequest < Struct.new( :contact_list_name, :filter, :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The number of contacts that may be returned at once, which is dependent on if there are more or less contacts than the value of the PageSize. Use this parameter to paginate results. If additional contacts exist beyond the specified limit, the NextToken element is sent in the response. Use the NextToken value in subsequent requests to retrieve additional contacts.
5093 5094 5095 5096 5097 5098 5099 5100 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5093 class ListContactsRequest < Struct.new( :contact_list_name, :filter, :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |