Class: Aws::SESV2::Types::ListCustomVerificationEmailTemplatesRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

Represents a request to list the existing custom verification email templates for your account.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

A token returned from a previous call to ListCustomVerificationEmailTemplates to indicate the position in the list of custom verification email templates.



5144
5145
5146
5147
5148
5149
# File 'lib/aws-sdk-sesv2/types.rb', line 5144

class ListCustomVerificationEmailTemplatesRequest < Struct.new(
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end

#page_sizeInteger

The number of results to show in a single call to ListCustomVerificationEmailTemplates. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results.

The value you specify has to be at least 1, and can be no more than 50.



5144
5145
5146
5147
5148
5149
# File 'lib/aws-sdk-sesv2/types.rb', line 5144

class ListCustomVerificationEmailTemplatesRequest < Struct.new(
  :next_token,
  :page_size)
  SENSITIVE = []
  include Aws::Structure
end