Class: Aws::SESV2::Types::ListMultiRegionEndpointsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListMultiRegionEndpointsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Represents a request to list all the multi-region endpoints (global-endpoints) whose primary region is the AWS-Region where operation is executed.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token returned from a previous call to
ListMultiRegionEndpointsto indicate the position in the list of multi-region endpoints (global-endpoints). -
#page_size ⇒ Integer
The number of results to show in a single call to
ListMultiRegionEndpoints.
Instance Attribute Details
#next_token ⇒ String
A token returned from a previous call to ListMultiRegionEndpoints to indicate the position in the list of multi-region endpoints (global-endpoints).
5608 5609 5610 5611 5612 5613 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5608 class ListMultiRegionEndpointsRequest < Struct.new( :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The number of results to show in a single call to ListMultiRegionEndpoints. If the number of results is larger than the number you specified in this parameter, the response includes a NextToken element that you can use to retrieve the next page of results.
5608 5609 5610 5611 5612 5613 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5608 class ListMultiRegionEndpointsRequest < Struct.new( :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |