Class: Aws::SESV2::Types::ListRecommendationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListRecommendationsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Represents a request to list the existing recommendations for your account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Hash<String,String>
Filters applied when retrieving recommendations.
-
#next_token ⇒ String
A token returned from a previous call to
ListRecommendationsto indicate the position in the list of recommendations. -
#page_size ⇒ Integer
The number of results to show in a single call to
ListRecommendations.
Instance Attribute Details
#filter ⇒ Hash<String,String>
Filters applied when retrieving recommendations. Can eiter be an
individual filter, or combinations of STATUS and IMPACT or
STATUS and TYPE
5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5920 class ListRecommendationsRequest < Struct.new( :filter, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token returned from a previous call to ListRecommendations to
indicate the position in the list of recommendations.
5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5920 class ListRecommendationsRequest < Struct.new( :filter, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The number of results to show in a single call to
ListRecommendations. If the number of results is larger than the
number you specified in this parameter, then the response includes a
NextToken element, which you can use to obtain additional results.
The value you specify has to be at least 1, and can be no more than 100.
5920 5921 5922 5923 5924 5925 5926 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5920 class ListRecommendationsRequest < Struct.new( :filter, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |