Class: Aws::SESV2::Types::ListRecommendationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListRecommendationsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Contains the response to your request to retrieve the list of recommendations for your account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A string token indicating that there might be additional recommendations available to be listed.
-
#recommendations ⇒ Array<Types::Recommendation>
The recommendations applicable to your account.
Instance Attribute Details
#next_token ⇒ String
A string token indicating that there might be additional
recommendations available to be listed. Use the token provided in
the ListRecommendationsResponse to use in the subsequent call to
ListRecommendations with the same parameters to retrieve the next
page of recommendations.
5945 5946 5947 5948 5949 5950 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5945 class ListRecommendationsResponse < Struct.new( :recommendations, :next_token) SENSITIVE = [] include Aws::Structure end |
#recommendations ⇒ Array<Types::Recommendation>
The recommendations applicable to your account.
5945 5946 5947 5948 5949 5950 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5945 class ListRecommendationsResponse < Struct.new( :recommendations, :next_token) SENSITIVE = [] include Aws::Structure end |