Class: Aws::SESV2::Types::ListResourceTenantsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListResourceTenantsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Represents a request to list tenants associated with a specific resource.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token returned from a previous call to
ListResourceTenantsto indicate the position in the list of resource tenants. -
#page_size ⇒ Integer
The number of results to show in a single call to
ListResourceTenants. -
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource to list associated tenants for.
Instance Attribute Details
#next_token ⇒ String
A token returned from a previous call to ListResourceTenants to indicate the position in the list of resource tenants.
5773 5774 5775 5776 5777 5778 5779 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5773 class ListResourceTenantsRequest < Struct.new( :resource_arn, :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The number of results to show in a single call to ListResourceTenants. If the number of results is larger than the number you specified in this parameter, then the response includes a NextToken element, which you can use to obtain additional results.
5773 5774 5775 5776 5777 5778 5779 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5773 class ListResourceTenantsRequest < Struct.new( :resource_arn, :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the resource to list associated tenants for.
5773 5774 5775 5776 5777 5778 5779 |
# File 'lib/aws-sdk-sesv2/types.rb', line 5773 class ListResourceTenantsRequest < Struct.new( :resource_arn, :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |