Class: Aws::SESV2::Types::ListSuppressedDestinationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListSuppressedDestinationsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to obtain a list of email destinations that are on the suppression list for your account or for a specific tenant.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_date ⇒ Time
Used to filter the list of suppressed email destinations so that it only includes addresses that were added to the list before a specific date.
-
#next_token ⇒ String
A token returned from a previous call to
ListSuppressedDestinationsto indicate the position in the list of suppressed email addresses. -
#page_size ⇒ Integer
The number of results to show in a single call to
ListSuppressedDestinations. -
#reasons ⇒ Array<String>
The factors that caused the email address to be added to the suppression list for your account or for a specific tenant.
-
#start_date ⇒ Time
Used to filter the list of suppressed email destinations so that it only includes addresses that were added to the list after a specific date.
-
#tenant_name ⇒ String
The name of the tenant whose suppression list you want to retrieve.
Instance Attribute Details
#end_date ⇒ Time
Used to filter the list of suppressed email destinations so that it only includes addresses that were added to the list before a specific date.
6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6102 class ListSuppressedDestinationsRequest < Struct.new( :tenant_name, :reasons, :start_date, :end_date, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token returned from a previous call to
ListSuppressedDestinations to indicate the position in the list of
suppressed email addresses.
6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6102 class ListSuppressedDestinationsRequest < Struct.new( :tenant_name, :reasons, :start_date, :end_date, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The number of results to show in a single call to
ListSuppressedDestinations. If the number of results is larger
than the number you specified in this parameter, then the response
includes a NextToken element, which you can use to obtain
additional results.
6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6102 class ListSuppressedDestinationsRequest < Struct.new( :tenant_name, :reasons, :start_date, :end_date, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#reasons ⇒ Array<String>
The factors that caused the email address to be added to the suppression list for your account or for a specific tenant.
6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6102 class ListSuppressedDestinationsRequest < Struct.new( :tenant_name, :reasons, :start_date, :end_date, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#start_date ⇒ Time
Used to filter the list of suppressed email destinations so that it only includes addresses that were added to the list after a specific date.
6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6102 class ListSuppressedDestinationsRequest < Struct.new( :tenant_name, :reasons, :start_date, :end_date, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |
#tenant_name ⇒ String
The name of the tenant whose suppression list you want to retrieve. If you omit this parameter, the operation targets the account-level suppression list.
6102 6103 6104 6105 6106 6107 6108 6109 6110 6111 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6102 class ListSuppressedDestinationsRequest < Struct.new( :tenant_name, :reasons, :start_date, :end_date, :next_token, :page_size) SENSITIVE = [] include Aws::Structure end |