Class: Aws::SESV2::Types::ListSuppressedDestinationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListSuppressedDestinationsResponse
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A list of suppressed email addresses.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
A token that indicates that there are additional email addresses on the suppression list for your account or for the specified tenant.
-
#suppressed_destination_summaries ⇒ Array<Types::SuppressedDestinationSummary>
A list of summaries, each containing a summary for a suppressed email destination.
Instance Attribute Details
#next_token ⇒ String
A token that indicates that there are additional email addresses on
the suppression list for your account or for the specified tenant.
To view additional suppressed addresses, issue another request to
ListSuppressedDestinations, and pass this token in the NextToken
parameter.
6130 6131 6132 6133 6134 6135 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6130 class ListSuppressedDestinationsResponse < Struct.new( :suppressed_destination_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#suppressed_destination_summaries ⇒ Array<Types::SuppressedDestinationSummary>
A list of summaries, each containing a summary for a suppressed email destination.
6130 6131 6132 6133 6134 6135 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6130 class ListSuppressedDestinationsResponse < Struct.new( :suppressed_destination_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |