Class: Aws::SESV2::Types::ListTenantResourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::ListTenantResourcesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Represents a request to list resources associated with a specific tenant.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter ⇒ Hash<String,String>
A map of filter keys and values for filtering the list of tenant resources.
-
#next_token ⇒ String
A token returned from a previous call to
ListTenantResourcesto indicate the position in the list of tenant resources. -
#page_size ⇒ Integer
The number of results to show in a single call to
ListTenantResources. -
#tenant_name ⇒ String
The name of the tenant to list resources for.
Instance Attribute Details
#filter ⇒ Hash<String,String>
A map of filter keys and values for filtering the list of tenant
resources. Currently, the only supported filter key is
RESOURCE_TYPE.
6191 6192 6193 6194 6195 6196 6197 6198 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6191 class ListTenantResourcesRequest < Struct.new( :tenant_name, :filter, :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
A token returned from a previous call to ListTenantResources to
indicate the position in the list of tenant resources.
6191 6192 6193 6194 6195 6196 6197 6198 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6191 class ListTenantResourcesRequest < Struct.new( :tenant_name, :filter, :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#page_size ⇒ Integer
The number of results to show in a single call to
ListTenantResources. If the number of results is larger than the
number you specified in this parameter, then the response includes a
NextToken element, which you can use to obtain additional results.
6191 6192 6193 6194 6195 6196 6197 6198 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6191 class ListTenantResourcesRequest < Struct.new( :tenant_name, :filter, :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |
#tenant_name ⇒ String
The name of the tenant to list resources for.
6191 6192 6193 6194 6195 6196 6197 6198 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6191 class ListTenantResourcesRequest < Struct.new( :tenant_name, :filter, :page_size, :next_token) SENSITIVE = [] include Aws::Structure end |