Class: Aws::SESV2::Types::PricingAttributes
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::PricingAttributes
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
The pricing attributes that apply to your Amazon SES account, including the currently active pricing plan and any scheduled change for the next billing cycle.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_plan ⇒ String
The pricing plan that is currently active on your Amazon SES account.
-
#next_plan ⇒ String
The pricing plan that will become active at the start of the next billing cycle, if a scheduled change has been requested.
Instance Attribute Details
#current_plan ⇒ String
The pricing plan that is currently active on your Amazon SES account.
6587 6588 6589 6590 6591 6592 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6587 class PricingAttributes < Struct.new( :current_plan, :next_plan) SENSITIVE = [] include Aws::Structure end |
#next_plan ⇒ String
The pricing plan that will become active at the start of the next billing cycle, if a scheduled change has been requested. This field is empty when no scheduled change is pending.
6587 6588 6589 6590 6591 6592 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6587 class PricingAttributes < Struct.new( :current_plan, :next_plan) SENSITIVE = [] include Aws::Structure end |