Class: Aws::SESV2::Types::PutAccountPricingAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::PutAccountPricingAttributesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to set the pricing plan for your Amazon SES account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#plan ⇒ String
The pricing plan to apply to your Amazon SES account.
Instance Attribute Details
#plan ⇒ String
The pricing plan to apply to your Amazon SES account. Can be one of the following:
-
NONE– No pricing plan is applied; billing follows per-feature pricing. -
ESSENTIALS– Baseline Amazon SES capabilities and select premium features. -
PRO– Includes everything inESSENTIALS, plus additional premium features for growing senders. -
ENTERPRISE– Includes everything inPRO, plus features intended for large-scale senders.
6698 6699 6700 6701 6702 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6698 class PutAccountPricingAttributesRequest < Struct.new( :plan) SENSITIVE = [] include Aws::Structure end |