Class: Aws::SESV2::Types::PutConfigurationSetSuppressionOptionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::PutConfigurationSetSuppressionOptionsRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to change the suppression list preferences for a specific configuration set.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration_set_name ⇒ String
The name of the configuration set to change the suppression list preferences for.
-
#suppressed_reasons ⇒ Array<String>
A list that contains the reasons that email addresses are automatically added to the suppression list for your account or for a specific tenant.
-
#suppression_scope ⇒ String
The suppression scope for the configuration set.
-
#validation_options ⇒ Types::SuppressionValidationOptions
An object that contains information about the email address suppression preferences for the configuration set in the current Amazon Web Services Region.
Instance Attribute Details
#configuration_set_name ⇒ String
The name of the configuration set to change the suppression list preferences for.
6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6903 class PutConfigurationSetSuppressionOptionsRequest < Struct.new( :configuration_set_name, :suppression_scope, :suppressed_reasons, :validation_options) SENSITIVE = [] include Aws::Structure end |
#suppressed_reasons ⇒ Array<String>
A list that contains the reasons that email addresses are automatically added to the suppression list for your account or for a specific tenant. This list can contain any or all of the following:
-
‘COMPLAINT` – Amazon SES adds an email address to the suppression list for your account or for a specific tenant when a message sent to that address results in a complaint.
-
‘BOUNCE` – Amazon SES adds an email address to the suppression list for your account or for a specific tenant when a message sent to that address results in a hard bounce.
6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6903 class PutConfigurationSetSuppressionOptionsRequest < Struct.new( :configuration_set_name, :suppression_scope, :suppressed_reasons, :validation_options) SENSITIVE = [] include Aws::Structure end |
#suppression_scope ⇒ String
The suppression scope for the configuration set. This overrides the tenant or account suppression scope for emails sent using this configuration set. Can be one of the following:
-
‘TENANT` – Use the tenant’s suppression list.
-
‘ACCOUNT` – Use the account-level suppression list.
6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6903 class PutConfigurationSetSuppressionOptionsRequest < Struct.new( :configuration_set_name, :suppression_scope, :suppressed_reasons, :validation_options) SENSITIVE = [] include Aws::Structure end |
#validation_options ⇒ Types::SuppressionValidationOptions
An object that contains information about the email address suppression preferences for the configuration set in the current Amazon Web Services Region.
6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/aws-sdk-sesv2/types.rb', line 6903 class PutConfigurationSetSuppressionOptionsRequest < Struct.new( :configuration_set_name, :suppression_scope, :suppressed_reasons, :validation_options) SENSITIVE = [] include Aws::Structure end |