Class: Aws::SESV2::Types::PutEmailIdentityFeedbackAttributesRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

A request to set the attributes that control how bounce and complaint events are processed.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#email_forwarding_enabledBoolean

Sets the feedback forwarding configuration for the identity.

If the value is true, you receive email notifications when bounce or complaint events occur. These notifications are sent to the address that you specified in the Return-Path header of the original email.

You're required to have a method of tracking bounces and complaints. If you haven't set up another mechanism for receiving bounce or complaint notifications (for example, by setting up an event destination), you receive an email notification when these events occur (even if this setting is disabled).

Returns:

  • (Boolean)


7411
7412
7413
7414
7415
7416
# File 'lib/aws-sdk-sesv2/types.rb', line 7411

class PutEmailIdentityFeedbackAttributesRequest < Struct.new(
  :email_identity,
  :email_forwarding_enabled)
  SENSITIVE = []
  include Aws::Structure
end

#email_identityString

The email identity.

Returns:

  • (String)


7411
7412
7413
7414
7415
7416
# File 'lib/aws-sdk-sesv2/types.rb', line 7411

class PutEmailIdentityFeedbackAttributesRequest < Struct.new(
  :email_identity,
  :email_forwarding_enabled)
  SENSITIVE = []
  include Aws::Structure
end