Class: Aws::SESV2::Types::PutSuppressedDestinationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::PutSuppressedDestinationRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to add an email destination to the suppression list for your account or for a specific tenant.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#email_address ⇒ String
The email address that should be added to the suppression list for your account or for the specified tenant.
-
#reason ⇒ String
The factors that should cause the email address to be added to the suppression list for your account or for the specified tenant.
-
#tenant_name ⇒ String
The name of the tenant whose suppression list you want to add the address to.
Instance Attribute Details
#email_address ⇒ String
The email address that should be added to the suppression list for your account or for the specified tenant.
7412 7413 7414 7415 7416 7417 7418 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7412 class PutSuppressedDestinationRequest < Struct.new( :email_address, :reason, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The factors that should cause the email address to be added to the suppression list for your account or for the specified tenant.
7412 7413 7414 7415 7416 7417 7418 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7412 class PutSuppressedDestinationRequest < Struct.new( :email_address, :reason, :tenant_name) SENSITIVE = [] include Aws::Structure end |
#tenant_name ⇒ String
The name of the tenant whose suppression list you want to add the address to. If you omit this parameter, the address is added to the account-level suppression list.
7412 7413 7414 7415 7416 7417 7418 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7412 class PutSuppressedDestinationRequest < Struct.new( :email_address, :reason, :tenant_name) SENSITIVE = [] include Aws::Structure end |