Class: Aws::SESV2::Types::PutTenantSuppressionAttributesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::PutTenantSuppressionAttributesRequest
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
A request to configure the suppression list preferences for a tenant.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#suppressed_reasons ⇒ Array<String>
A list that contains the reasons that email addresses are automatically added to the suppression list for the tenant.
-
#suppression_scope ⇒ String
The suppression scope for the tenant.
-
#tenant_name ⇒ String
The name of the tenant to configure suppression list preferences for.
Instance Attribute Details
#suppressed_reasons ⇒ Array<String>
A list that contains the reasons that email addresses are automatically added to the suppression list for the tenant. This list can contain any or all of the following:
-
‘COMPLAINT` – Amazon SES adds an email address to the suppression list when a message sent to that address results in a complaint.
-
‘BOUNCE` – Amazon SES adds an email address to the suppression list when a message sent to that address results in a hard bounce.
7459 7460 7461 7462 7463 7464 7465 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7459 class PutTenantSuppressionAttributesRequest < Struct.new( :tenant_name, :suppressed_reasons, :suppression_scope) SENSITIVE = [] include Aws::Structure end |
#suppression_scope ⇒ String
The suppression scope for the tenant. Specify ‘TENANT` to use the tenant’s own suppression list, or ‘ACCOUNT` to use the account-level suppression list.
<note markdown=“1”> If you don’t specify a suppression scope, the tenant defaults to ‘ACCOUNT` scope and uses the account-level suppression list.
</note>
7459 7460 7461 7462 7463 7464 7465 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7459 class PutTenantSuppressionAttributesRequest < Struct.new( :tenant_name, :suppressed_reasons, :suppression_scope) SENSITIVE = [] include Aws::Structure end |
#tenant_name ⇒ String
The name of the tenant to configure suppression list preferences for.
7459 7460 7461 7462 7463 7464 7465 |
# File 'lib/aws-sdk-sesv2/types.rb', line 7459 class PutTenantSuppressionAttributesRequest < Struct.new( :tenant_name, :suppressed_reasons, :suppression_scope) SENSITIVE = [] include Aws::Structure end |