Class: Aws::SESV2::Types::SendQuota
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::SendQuota
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
An object that contains information about the per-day and per-second sending limits for your Amazon SES account in the current Amazon Web Services Region.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_24_hour_send ⇒ Float
The maximum number of emails that you can send in the current Amazon Web Services Region over a 24-hour period.
-
#max_send_rate ⇒ Float
The maximum number of emails that you can send per second in the current Amazon Web Services Region.
-
#sent_last_24_hours ⇒ Float
The number of emails sent from your Amazon SES account in the current Amazon Web Services Region over the past 24 hours.
Instance Attribute Details
#max_24_hour_send ⇒ Float
The maximum number of emails that you can send in the current Amazon Web Services Region over a 24-hour period. A value of -1 signifies an unlimited quota. (This value is also referred to as your sending quota.)
8220 8221 8222 8223 8224 8225 8226 |
# File 'lib/aws-sdk-sesv2/types.rb', line 8220 class SendQuota < Struct.new( :max_24_hour_send, :max_send_rate, :sent_last_24_hours) SENSITIVE = [] include Aws::Structure end |
#max_send_rate ⇒ Float
The maximum number of emails that you can send per second in the current Amazon Web Services Region. This value is also called your maximum sending rate or your maximum TPS (transactions per second) rate.
8220 8221 8222 8223 8224 8225 8226 |
# File 'lib/aws-sdk-sesv2/types.rb', line 8220 class SendQuota < Struct.new( :max_24_hour_send, :max_send_rate, :sent_last_24_hours) SENSITIVE = [] include Aws::Structure end |
#sent_last_24_hours ⇒ Float
The number of emails sent from your Amazon SES account in the current Amazon Web Services Region over the past 24 hours.
8220 8221 8222 8223 8224 8225 8226 |
# File 'lib/aws-sdk-sesv2/types.rb', line 8220 class SendQuota < Struct.new( :max_24_hour_send, :max_send_rate, :sent_last_24_hours) SENSITIVE = [] include Aws::Structure end |