Class: Aws::SESV2::Types::SuppressionConditionThreshold
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::SuppressionConditionThreshold
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
Contains Auto Validation settings, allowing you to suppress sending to specific destination(s) if they do not meet required threshold. For details on Auto Validation, see Auto Validation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#condition_threshold_enabled ⇒ String
Indicates whether Auto Validation is enabled for suppression.
-
#overall_confidence_threshold ⇒ Types::SuppressionConfidenceThreshold
The overall confidence threshold used to determine suppression decisions.
Instance Attribute Details
#condition_threshold_enabled ⇒ String
Indicates whether Auto Validation is enabled for suppression. Set to
ENABLED to enable the Auto Validation feature, or set to
DISABLED to disable it.
8452 8453 8454 8455 8456 8457 |
# File 'lib/aws-sdk-sesv2/types.rb', line 8452 class SuppressionConditionThreshold < Struct.new( :condition_threshold_enabled, :overall_confidence_threshold) SENSITIVE = [] include Aws::Structure end |
#overall_confidence_threshold ⇒ Types::SuppressionConfidenceThreshold
The overall confidence threshold used to determine suppression decisions.
8452 8453 8454 8455 8456 8457 |
# File 'lib/aws-sdk-sesv2/types.rb', line 8452 class SuppressionConditionThreshold < Struct.new( :condition_threshold_enabled, :overall_confidence_threshold) SENSITIVE = [] include Aws::Structure end |