Class: Aws::SESV2::Types::UpdateEmailIdentityPolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Aws::Structure
Defined in:
lib/aws-sdk-sesv2/types.rb

Overview

Represents a request to update a sending authorization policy for an identity. Sending authorization is an Amazon SES feature that enables you to authorize other senders to use your identities. For information, see the Amazon SES Developer Guide.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#email_identityString

The email identity.

Returns:

  • (String)


9199
9200
9201
9202
9203
9204
9205
# File 'lib/aws-sdk-sesv2/types.rb', line 9199

class UpdateEmailIdentityPolicyRequest < Struct.new(
  :email_identity,
  :policy_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end

#policyString

The text of the policy in JSON format. The policy cannot exceed 4 KB.

For information about the syntax of sending authorization policies, see the Amazon SES Developer Guide.

Returns:

  • (String)


9199
9200
9201
9202
9203
9204
9205
# File 'lib/aws-sdk-sesv2/types.rb', line 9199

class UpdateEmailIdentityPolicyRequest < Struct.new(
  :email_identity,
  :policy_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end

#policy_nameString

The name of the policy.

The policy name cannot exceed 64 characters and can only include alphanumeric characters, dashes, and underscores.

Returns:

  • (String)


9199
9200
9201
9202
9203
9204
9205
# File 'lib/aws-sdk-sesv2/types.rb', line 9199

class UpdateEmailIdentityPolicyRequest < Struct.new(
  :email_identity,
  :policy_name,
  :policy)
  SENSITIVE = []
  include Aws::Structure
end