Class: Aws::SESV2::Types::VolumeStatistics
- Inherits:
-
Struct
- Object
- Struct
- Aws::SESV2::Types::VolumeStatistics
- Includes:
- Aws::Structure
- Defined in:
- lib/aws-sdk-sesv2/types.rb
Overview
An object that contains information about the amount of email that was delivered to recipients.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#inbox_raw_count ⇒ Integer
The total number of emails that arrived in recipients' inboxes.
-
#projected_inbox ⇒ Integer
An estimate of the percentage of emails sent from the current domain that will arrive in recipients' inboxes.
-
#projected_spam ⇒ Integer
An estimate of the percentage of emails sent from the current domain that will arrive in recipients' spam or junk mail folders.
-
#spam_raw_count ⇒ Integer
The total number of emails that arrived in recipients' spam or junk mail folders.
Instance Attribute Details
#inbox_raw_count ⇒ Integer
The total number of emails that arrived in recipients' inboxes.
9477 9478 9479 9480 9481 9482 9483 9484 |
# File 'lib/aws-sdk-sesv2/types.rb', line 9477 class VolumeStatistics < Struct.new( :inbox_raw_count, :spam_raw_count, :projected_inbox, :projected_spam) SENSITIVE = [] include Aws::Structure end |
#projected_inbox ⇒ Integer
An estimate of the percentage of emails sent from the current domain that will arrive in recipients' inboxes.
9477 9478 9479 9480 9481 9482 9483 9484 |
# File 'lib/aws-sdk-sesv2/types.rb', line 9477 class VolumeStatistics < Struct.new( :inbox_raw_count, :spam_raw_count, :projected_inbox, :projected_spam) SENSITIVE = [] include Aws::Structure end |
#projected_spam ⇒ Integer
An estimate of the percentage of emails sent from the current domain that will arrive in recipients' spam or junk mail folders.
9477 9478 9479 9480 9481 9482 9483 9484 |
# File 'lib/aws-sdk-sesv2/types.rb', line 9477 class VolumeStatistics < Struct.new( :inbox_raw_count, :spam_raw_count, :projected_inbox, :projected_spam) SENSITIVE = [] include Aws::Structure end |
#spam_raw_count ⇒ Integer
The total number of emails that arrived in recipients' spam or junk mail folders.
9477 9478 9479 9480 9481 9482 9483 9484 |
# File 'lib/aws-sdk-sesv2/types.rb', line 9477 class VolumeStatistics < Struct.new( :inbox_raw_count, :spam_raw_count, :projected_inbox, :projected_spam) SENSITIVE = [] include Aws::Structure end |